@@ -26,9 +26,9 @@
 // position of the image in space with respect to some world coordinate
 // system are extremely important.
 //
-// Image origin and spacing are fundamental to many
+// Image origin, image voxel directions (i.e. orientation) and spacing are fundamental to many
 // applications. Registration, for example, is performed in physical
-// coordinates. Improperly defined spacing and origins will result in
+// coordinates. Improperly defined spacing, direction, and origins will result in
 // inconsistent results in such processes. Medical images with no spatial
 // information should not be used for medical diagnosis, image analysis,
 // feature extraction, assisted radiation therapy or image guided surgery. In
@@ -43,12 +43,19 @@
 // \end{figure}
 //
 // Figure \ref{fig:ImageOriginAndSpacing} illustrates the main geometrical
-// concepts associated with the \doxygen{Image}. In this figure, circles are
+// concepts associated with the \doxygen{Image}.
+// In this figure, circles are
 // used to represent the center of pixels. The value of the pixel is assumed
 // to exist as a Dirac Delta Function located at the pixel center. Pixel
 // spacing is measured between the pixel centers and can be different along
 // each dimension. The image origin is associated with the coordinates of the
-// first pixel in the image. A \emph{pixel} is considered to be the
+// first pixel in the image.
+// For this simplified example, the voxel lattice is perfectly aligned with physical
+// space orientation, and the image direction is therefore an identity mapping.  If the
+// voxel lattice samples were rotated with respect to physical space, then the image direction
+// would contain a rotation matrix with respect.
+//
+// A \emph{pixel} is considered to be the
 // rectangular region surrounding the pixel center holding the data
 // value. This can be viewed as the Voronoi region of the image grid, as
 // illustrated in the right side of the figure.  Linear interpolation of
@@ -59,9 +66,20 @@
 
 #include "itkImage.h"
 
+// Function to simulate getting mouse click from an image
+static itk::Image< unsigned short, 3 >::IndexType GetIndexFromMouseClick()
+{
+  itk::Image< unsigned short, 3 >::IndexType LeftEyeIndex;
+  LeftEyeIndex[0]=60;
+  LeftEyeIndex[1]=127;
+  LeftEyeIndex[2]=93;
+  return LeftEyeIndex;
+}
+
 int main(int, char *[])
 {
-  typedef itk::Image< unsigned short, 3 > ImageType;
+  const unsigned int Dimension=3;
+  typedef itk::Image< unsigned short, Dimension > ImageType;
   ImageType::Pointer image = ImageType::New();
 
   const ImageType::SizeType  size  = {{ 200, 200, 200}}; //Size along {X,Y,Z}
@@ -72,9 +90,8 @@ int main(int, char *[])
   region.SetIndex( start );
 
   image->SetRegions( region );
-  image->Allocate();
-
-  image->FillBuffer( 0 );
+  image->Allocate(true); // initialize buffer
+                                                // to zero
 
   // Software Guide : BeginLatex
   //
@@ -151,9 +168,9 @@ int main(int, char *[])
 
   // Software Guide : BeginCodeSnippet
   // coordinates of the center of the first pixel in N-D
-  ImageType::PointType origin;
-  origin.Fill(0.0);
-  image->SetOrigin( origin );
+  ImageType::PointType newOrigin;
+  newOrigin.Fill(0.0);
+  image->SetOrigin( newOrigin );
   // Software Guide : EndCodeSnippet
 
   //  Software Guide : BeginLatex
@@ -167,15 +184,63 @@ int main(int, char *[])
   //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
-  const ImageType::PointType& orgn = image->GetOrigin();
+  const ImageType::PointType & origin = image->GetOrigin();
 
   std::cout << "Origin = ";
-  std::cout << orgn[0] << ", " << orgn[1] << ", " << orgn[2] << std::endl;
+  std::cout << origin[0] << ", " << origin[1] << ", " << origin[2] << std::endl;
+
+  // Software Guide : EndCodeSnippet
+
+  //TODO: This example should really be writen for a more complicated direction cosine. i.e.
+  //     As the first index element increases, the 1st physcial space decreases.
+
+  //  Software Guide : BeginLatex
+  //
+  // The image direction matrix represents the orientation relationships between
+  // the image samples and physical space coordinate systems.  The image direction
+  // matrix is an orthonormal matrix that describes the possible permutation of image Index
+  // values and the rotational aspects that are needed to properly reconcile image index
+  // organization with physical space axis.
+  // The image directions is a $N x N$ matrix where $N$ is the dimension of the image. An
+  // identity image direction indicates that increasing values of the 1st, 2nd, 3rd index element corresponds
+  // to increasing values the 1st, 2nd and 3rd physcial space axis respectively, and that the voxel
+  // samples are perfectly aligned with the physical space axis.
+  //
+  // The following code illustrates the creation and assignment of a variable
+  // suitable for initializing the image direction with an identity.
+  //
+  // \index{itk::Image!direction}
+  // \index{itk::Image!SetDirection()}
+  //
+  // Software Guide : EndLatex
+
+  // Software Guide : BeginCodeSnippet
+  // coordinates of the center of the first pixel in N-D
+  ImageType::DirectionType direction;
+  direction.SetIdentity();
+  image->SetDirection( direction );
+  // Software Guide : EndCodeSnippet
+
+  //  Software Guide : BeginLatex
+  //
+  //  The direction can also be retrieved from an image by using the
+  //  \code{GetDirection()} method. This will return a reference to a
+  //  \code{Matrix}. The reference can be used to read the contents of
+  //  the array. Note again the use of the \code{const} keyword to indicate
+  //  that the matrix contents can not be modified.
+  //
+  //  Software Guide : EndLatex
+
+  // Software Guide : BeginCodeSnippet
+  const ImageType::DirectionType& direct = image->GetDirection();
+
+  std::cout << "Direction = " << std::endl;
+  std::cout << direct << std::endl;
   // Software Guide : EndCodeSnippet
 
   // Software Guide : BeginLatex
   //
-  // Once the spacing and origin of the image have been initialized, the image
+  // Once the spacing, origin, and direction of the image samples have been initialized, the image
   // will correctly map pixel indices to and from physical space
   // coordinates. The following code illustrates how a point in physical
   // space can be mapped into an image index for the purpose of reading the
@@ -246,7 +311,7 @@ int main(int, char *[])
   // Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
-  bool isInside = image->TransformPhysicalPointToIndex( point, pixelIndex );
+  const bool isInside = image->TransformPhysicalPointToIndex( point, pixelIndex );
   if ( isInside )
     {
     ImageType::PixelType pixelValue = image->GetPixel( pixelIndex );
@@ -262,5 +327,106 @@ int main(int, char *[])
   // used when massive access to pixel data is required.
   //
   // Software Guide : EndLatex
+  //
+
+  //  Software Guide : BeginLatex
+  //
+  //  The following example illustrates the mathematical relationships between
+  //  Image Index locations and it's corresponding Physical Point representation
+  //  for a given Image.
+  //
+  // \index{itk::Image!PhysicalPoint}
+  // \index{itk::Image!Index}
+  //
+  // Let us imagine that a graphical user interface exists
+  // where the end user manually selects the voxel index location
+  // of the left eye in a volume with a mouse interface.  We need to
+  // convert that index location to a physical location so that
+  // laser guided surgery can be accurately performed.
+  //
+  // SoftwareGuide : EndLatex
+
+  // Software Guide : BeginLatex
+  //
+  // Use a predefined function: TransformIndexToPhysicalPoint
+  // SoftwareGuide : EndLatex
+
+  // Software Guide : BeginCodeSnippet
+  const ImageType::IndexType LeftEyeIndex = GetIndexFromMouseClick();
+  ImageType::PointType LeftEyePoint;
+  image->TransformIndexToPhysicalPoint(LeftEyeIndex,LeftEyePoint);
+  // Software Guide : EndCodeSnippet
+
+  std::cout << "===========================================" << std::endl;
+  std::cout << "The Left Eye Location is " << LeftEyePoint << std::endl;
+
+  // Software Guide : BeginLatex
+  //
+  // For a given index $I_{3X1}$, the physical location $P_{3X1}$ is calculated
+  // as following:
+  //
+  // \begin{equation}
+  //   P_{3X1} = O_{3X1} + D_{3X3} * diag( S_{3X1} )_{3x3} * I_{3X1}
+  // \end{equation}
+  // , where $D$ is an orthonormal direction cosines matrix and
+  // $S$ is the image spacing diagonal matrix.
+  //
+  // In matlab syntax the conversions are:
+  //
+  // \begin{verbatim}
+  // % Non-identity Spacing and Direction
+  // spacing=diag( [0.9375, 0.9375, 1.5] );
+  // direction=[0.998189, 0.0569345, -0.0194113;
+  //            0.0194429, -7.38061e-08, 0.999811;
+  //            0.0569237, -0.998378, -0.00110704];
+  // point = origin + direction * spacing * LeftEyeIndex
+  // \end{verbatim}
+  //
+  // A corresponding mathematical expansion of the C/C++ code is:
+  // SoftwareGuide : EndLatex
+
+  // Software Guide : BeginCodeSnippet
+  typedef itk::Matrix<double, Dimension, Dimension> MatrixType;
+  MatrixType SpacingMatrix;
+  SpacingMatrix.Fill( 0.0F );
+
+  const ImageType::SpacingType & ImageSpacing = image->GetSpacing();
+  SpacingMatrix( 0,0 ) = ImageSpacing[0];
+  SpacingMatrix( 1,1 ) = ImageSpacing[1];
+  SpacingMatrix( 2,2 ) = ImageSpacing[2];
+
+  const ImageType::DirectionType & ImageDirectionCosines = image->GetDirection();
+  const ImageType::PointType &ImageOrigin = image->GetOrigin();
+
+  typedef itk::Vector< double, Dimension > VectorType;
+  VectorType LeftEyeIndexVector;
+  LeftEyeIndexVector[0]= LeftEyeIndex[0];
+  LeftEyeIndexVector[1]= LeftEyeIndex[1];
+  LeftEyeIndexVector[2]= LeftEyeIndex[2];
+
+  ImageType::PointType LeftEyePointByHand =
+     ImageOrigin + ImageDirectionCosines * SpacingMatrix * LeftEyeIndexVector;
+  // Software Guide : EndCodeSnippet
+
+  std::cout << "===========================================" << std::endl;
+  std::cout << "Spacing:: " << std::endl << SpacingMatrix << std::endl;
+  std::cout << "===========================================" << std::endl;
+  std::cout << "DirectionCosines:: " << std::endl << ImageDirectionCosines << std::endl;
+  std::cout << "===========================================" << std::endl;
+  std::cout << "Origin:: " << std::endl << ImageOrigin << std::endl;
+  std::cout << "===========================================" << std::endl;
+  std::cout << "The Left Eye Location is " << LeftEyePointByHand << std::endl;
+
+  //
+  // Check if two results are identical
+  //
+  if ( (LeftEyePointByHand - LeftEyePoint).GetNorm() < 0.01F )
+  {
+    std::cout << "===========================================" << std::endl;
+    std::cout << "Two results are identical as expected!" << std::endl;
+    std::cout << "The Left Eye from TransformIndexToPhysicalPoint is " << LeftEyePoint << std::endl;
+    std::cout << "The Left Eye from Math is " << LeftEyePointByHand << std::endl;
+  }
+
   return EXIT_SUCCESS;
 }
