@@ -102,11 +102,11 @@ int main(int, char *[])
   for(unsigned int i=0; i<360; i++)
     {
     const double angle = i * vnl_math::pi / 180.0;
-    point[0] = radius * vcl_sin( angle );
-    point[1] = radius * vcl_cos( angle );
+    point[0] = radius * std::sin( angle );
+    point[1] = radius * std::cos( angle );
     point[2] = 1.0;   // flat on the Z plane
-    tangent[0] =  vcl_cos(angle);
-    tangent[1] = -vcl_sin(angle);
+    tangent[0] =  std::cos(angle);
+    tangent[1] = -std::sin(angle);
     tangent[2] = 0.0;  // flat on the Z plane
     pointSet->SetPoint( pointId, point );
     pointSet->SetPointData( pointId, tangent );
