@@ -99,7 +99,7 @@ int main( int argc, char ** argv )
         {
         ShapedNeighborhoodIteratorType::OffsetType off;
 
-        float dis = vcl_sqrt( x*x + y*y );
+        float dis = std::sqrt( x*x + y*y );
         if (dis <= rad)
           {
           off[0] = static_cast<int>(x);
