@@ -117,7 +117,7 @@ private:
 protected:
   VTKImageExportBase();
   ~VTKImageExportBase() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   typedef DataObject::Pointer DataObjectPointer;
 
