@@ -146,7 +146,7 @@ public:
 protected:
   DICOMSeriesFileNames();
   ~DICOMSeriesFileNames() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   DICOMSeriesFileNames(const Self &); //purposely not implemented
