@@ -151,7 +151,7 @@ protected:
   /**
    * Method to print the object.
    */
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /**
    * Points that the spline attempts to intepolate.
