@@ -87,7 +87,7 @@ public:
 protected:
   AutoPointerDataObjectDecorator();
   ~AutoPointerDataObjectDecorator();
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 protected:
 
