@@ -55,10 +55,10 @@ public:
 
   /** Evaluate the function. */
   inline TRealValueType Evaluate(const TRealValueType & u) const
-  { return ( vcl_exp( static_cast< TRealValueType >(-0.5) * vnl_math_sqr(u) ) * m_Factor ); }
+  { return ( std::exp( static_cast< TRealValueType >(-0.5) * vnl_math_sqr(u) ) * m_Factor ); }
 
 protected:
-  GaussianKernelFunction(): m_Factor(  NumericTraits< TRealValueType >::One / vcl_sqrt(static_cast< TRealValueType >(2.0 * vnl_math::pi )) ) {};
+  GaussianKernelFunction(): m_Factor(  NumericTraits< TRealValueType >::One / std::sqrt(static_cast< TRealValueType >(2.0 * vnl_math::pi )) ) {};
   virtual ~GaussianKernelFunction() {};
   void PrintSelf(std::ostream & os, Indent indent) const
   { Superclass::PrintSelf(os, indent); }
