@@ -86,7 +86,7 @@ public:
 protected:
   ImageDuplicator();
   virtual ~ImageDuplicator() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   ImageDuplicator(const Self &); //purposely not implemented
