@@ -162,6 +162,16 @@ private:
   LightObject(const Self &);    //purposely not implemented
   void operator=(const Self &); //purposely not implemented
 };
+
+/**
+ * This operator allows all subclasses of LightObject to be printed via <<.
+ * It in turn invokes the Print method, which in turn will invoke the
+ * PrintSelf method that all objects should define, if they have anything
+ * interesting to print out.
+ */
+std::ostream &
+operator<<(std::ostream & os, const LightObject & o);
+
 } // end namespace itk
 
 #endif
