@@ -18,6 +18,7 @@
 #ifndef __itkNeighborhoodAllocator_h
 #define __itkNeighborhoodAllocator_h
 #include <iostream>
+#include "itkMacro.h"
 
 namespace itk
 {
@@ -51,7 +52,7 @@ public:
   typedef const TPixel * const_iterator;
 
   /** Default constructor */
-  NeighborhoodAllocator():m_ElementCount(0), m_Data(0)  {}
+  NeighborhoodAllocator():m_ElementCount(0), m_Data(ITK_NULLPTR)  {}
 
   /** Default destructor */
   ~NeighborhoodAllocator()
