@@ -130,6 +130,9 @@ public:
   /** Resize the input vector to the specified size */
   static void SetLength(std::vector< T > & m, const unsigned int s)
   {
+    // since std::vector often holds types that have no NumericTraits::Zero,
+    // allow resize() to call the type's default constructor
+    m.clear();
     m.resize(s);
   }
 
