@@ -114,7 +114,7 @@ public:
 protected:
   ProgressAccumulator();
   virtual ~ProgressAccumulator();
-  void PrintSelf(std::ostream & s, Indent indent) const;
+  virtual void PrintSelf(std::ostream & s, Indent indent) const ITK_OVERRIDE;
 
 private:
   /**  Command for observing progress of pipeline filters */
