@@ -61,7 +61,11 @@ public:
   /** Start counting the change of value */
   void        Start(void);
 
-  /** Stop counting the change of value */
+  /** Stop counting the change of value.
+   *
+   * If a matching Start() has not been called before, there is no
+   * effect.
+   **/
   void        Stop(void);
 
   /** Returns the number of times that the probe has been started */
@@ -83,6 +87,9 @@ public:
    */
   MeanType    GetMean(void) const;
 
+  /** Reset the probe */
+  void        Reset(void);
+
 private:
 
   ValueType m_StartValue;
