@@ -65,7 +65,7 @@ public:
   /** Get the current time.
    *  Warning: the returned value is not the elapsed time since the last Start() call.
    */
-  virtual RealTimeClock::TimeStampType GetInstantValue(void) const;
+  virtual TimeStampType GetInstantValue(void) const ITK_OVERRIDE;
 
   /** Returns the average times passed between the starts and stops of the
    *  probe. See the RealTimeClock for details on the precision and units of
@@ -75,6 +75,9 @@ public:
    */
   itkLegacyMacro(TimeStampType GetMeanTime(void) const);
 
+  /** Get a handle to m_RealTimeClock. */
+  itkGetConstObjectMacro( RealTimeClock, RealTimeClock );
+
 private:
   RealTimeClock::Pointer m_RealTimeClock;
 };
