@@ -203,7 +203,7 @@ public:
 
   /** Set the versor using the right part.
    * the magnitude of the vector given is assumed to
-   * be equal to vcl_sin(angle/2).
+   * be equal to std::sin(angle/2).
    * This method will compute internally the scalar
    * part that preserve the Versor as a unit quaternion. */
   void Set(const VectorType & axis);
@@ -271,7 +271,7 @@ private:
     }
   static inline ValueType Epsilon()
     {
-      return Epsilon((ValueType *)0);
+      return Epsilon((ValueType *)ITK_NULLPTR);
     }
 
   /** Component parallel to x axis.  */
