@@ -498,7 +498,7 @@ FloatingPointExceptions
   act.sa_sigaction = fhdl;
   sigemptyset(&act.sa_mask);
   act.sa_flags = SA_SIGINFO;
-  sigaction(SIGFPE,&act,0);
+  sigaction(SIGFPE,&act,ITK_NULLPTR);
   FloatingPointExceptions::m_Enabled = true;
 }
 void
