@@ -134,7 +134,7 @@ ObjectFactoryBase::GetStrictVersionChecking()
 
 
 /**
- * Create an instance of a named itk object using the loaded
+ * Create an instance of a named ITK object using the loaded
  * factories
  */
 LightObject::Pointer
@@ -154,7 +154,7 @@ ObjectFactoryBase
       return newobject;
       }
     }
-  return 0;
+  return ITK_NULLPTR;
 }
 
 std::list< LightObject::Pointer >
@@ -222,9 +222,9 @@ void
 ObjectFactoryBase
 ::RegisterInternal()
 {
-  // Guaranee that no internal factories have already been registered.
-  itkAssertOrThrowMacro( ObjectFactoryBasePrivate::m_RegisteredFactories->empty(),
-                         "Factories unexpectedlly already registered!"  );
+  // Guarantee that no internal factories have already been registered.
+  itkAssertInDebugAndIgnoreInReleaseMacro( ObjectFactoryBasePrivate::m_RegisteredFactories->empty() );
+  ObjectFactoryBasePrivate::m_RegisteredFactories->clear();
 
   // Register all factories registered by the
   // "RegisterFactoryInternal" method
@@ -413,6 +413,15 @@ ObjectFactoryBase
           newfactory->m_LibraryHandle = (void *)lib;
           newfactory->m_LibraryPath = fullpath;
           newfactory->m_LibraryDate = 0; // unused for now...
+
+          // ObjectFactoryBase::RegisterFactory may raise an exception if
+          // a user enables StrictVersionChecking and a library in "path"
+          // is a conflicting version; this exception should be propagated
+          // to the user and not caught by ITK
+          //
+          // Do not edit the next comment line! It is intended to be parsed
+          // by the Coverity analyzer.
+          // coverity[fun_call_w_exception]
           if (!ObjectFactoryBase::RegisterFactory(newfactory))
             {
             DynamicLoader::CloseLibrary(lib);
@@ -446,7 +455,7 @@ ObjectFactoryBase
  */
 ObjectFactoryBase::ObjectFactoryBase()
 {
-  m_LibraryHandle = 0;
+  m_LibraryHandle = ITK_NULLPTR;
   m_LibraryDate = 0;
   m_OverrideMap = new OverRideMap;
 }
@@ -470,7 +479,7 @@ void
 ObjectFactoryBase
 ::RegisterFactoryInternal(ObjectFactoryBase *factory)
 {
-  if ( factory->m_LibraryHandle != NULL )
+  if ( factory->m_LibraryHandle != ITK_NULLPTR )
     {
     itkGenericExceptionMacro( "A dynamic factory tried to be loaded internally!" );
     }
@@ -497,7 +506,7 @@ bool
 ObjectFactoryBase
 ::RegisterFactory(ObjectFactoryBase *factory, InsertionPositionType where, size_t position)
 {
-  if ( factory->m_LibraryHandle == 0 )
+  if ( factory->m_LibraryHandle == ITK_NULLPTR )
     {
     const char nonDynamicName[] = "Non-Dynamicaly loaded factory";
     factory->m_LibraryPath = nonDynamicName;
@@ -692,7 +701,7 @@ ObjectFactoryBase
         }
       }
     delete ObjectFactoryBasePrivate::m_RegisteredFactories;
-    ObjectFactoryBasePrivate::m_RegisteredFactories = 0;
+    ObjectFactoryBasePrivate::m_RegisteredFactories = ITK_NULLPTR;
     ObjectFactoryBasePrivate::m_Initialized = false;
     }
 }
@@ -733,7 +742,7 @@ ObjectFactoryBase
       return ( *i ).second.m_CreateObject->CreateObject();
       }
     }
-  return 0;
+  return ITK_NULLPTR;
 }
 
 std::list< LightObject::Pointer >
