@@ -16,16 +16,21 @@
  *
  *=========================================================================*/
 #include "itkCompensatedSummation.h"
+#include "itkStdStreamStateSave.h"
 
 #include "itkMersenneTwisterRandomVariateGenerator.h"
 
 int itkCompensatedSummationTest( int, char * [] )
 {
+// Save the format stream variables for std::cout
+// They will be restored when coutState goes out of scope
+// scope.
+  itk::StdStreamStateSave coutState(std::cout);
+
   typedef float FloatType;
   long int seedValue = 17;
 
   const FloatType expectedMean = 0.5;
-  std::cout.precision( 22 );
 
   const itk::SizeValueType accumSize = 50000000;
 
