@@ -54,17 +54,18 @@ public:
     TestDomainThreader() {};
 
   private:
-    virtual void BeforeThreadedExecution()
+    virtual void BeforeThreadedExecution() ITK_OVERRIDE
       {
-      this->m_PerThreadCompensatedSum.resize( this->GetNumberOfThreadsUsed() );
-      for( itk::ThreadIdType i=0; i < this->GetNumberOfThreadsUsed(); i++ )
+      const itk::ThreadIdType numThreadsUsed = this->GetNumberOfThreadsUsed();
+      this->m_PerThreadCompensatedSum.resize( numThreadsUsed );
+      for( itk::ThreadIdType i = 0; i < numThreadsUsed; ++i )
         {
         this->m_PerThreadCompensatedSum[i].ResetToZero();
         }
       }
 
     virtual void ThreadedExecution( const DomainType& subdomain,
-                                    const itk::ThreadIdType threadId )
+                                    const itk::ThreadIdType threadId ) ITK_OVERRIDE
       {
       itk::CompensatedSummation<double> compensatedSum;
       for( DomainType::IndexValueType i=subdomain[0]; i <= subdomain[1]; i++ )
@@ -74,12 +75,12 @@ public:
         }
       }
 
-    virtual void AfterThreadedExecution()
+    virtual void AfterThreadedExecution() ITK_OVERRIDE
       {
       this->m_Associate->m_UncompensatedSumOfThreads = itk::NumericTraits<double>::Zero;
       this->m_Associate->m_CompensatedSumOfThreads.ResetToZero();
 
-      for( itk::ThreadIdType i = 0; i < this->GetNumberOfThreadsUsed(); ++i )
+      for( itk::ThreadIdType i = 0, numThreadsUsed = this->GetNumberOfThreadsUsed(); i < numThreadsUsed; ++i )
         {
         double sum = this->m_PerThreadCompensatedSum[i].GetSum();
         std::cout << i << ": " << sum << std::endl;
@@ -214,8 +215,8 @@ int itkCompensatedSummationTest2(int, char* [])
      * optimizations that were not handled by the CompensatedSummation class
      * pragmas, or perhaps because of differences in math coprocessors, or
      * something else. It's not clear. */
-    if( vcl_fabs( referenceSum - enclosingClass.GetCompensatedSumOfThreads() ) >
-        vcl_fabs( referenceSum - enclosingClass.GetUncompensatedSumOfThreads() ) )
+    if( std::fabs( referenceSum - enclosingClass.GetCompensatedSumOfThreads() ) >
+        std::fabs( referenceSum - enclosingClass.GetUncompensatedSumOfThreads() ) )
       {
       std::cerr << "Error. Expected the compensated sum of threads to be closer "
                 << "to reference than the uncompensated sum, or the same value. "
