@@ -18,11 +18,16 @@
 
 #include "itkMath.h"
 #include "itkIntTypes.h"
+#include "itkStdStreamStateSave.h"
+
 #include <iostream>
 
 int main( int, char *[] )
 {
-  std::cout.precision( 24 );
+// Save the format stream variables for std::cout
+// They will be restored when coutState goes out of scope
+// scope.
+  itk::StdStreamStateSave coutState(std::cout);
 
   std::cout << "e: " << itk::Math::e << std::endl;
   std::cout << "log2e: " << itk::Math::log2e << std::endl;
