@@ -42,7 +42,7 @@ template<typename T> void CheckVariableLengthArrayTraits(const T &t)
 #ifdef GCC_USEDEMANGLE
   char const *mangledName = typeid( t ).name();
   int         status;
-  char *      unmangled = abi::__cxa_demangle(mangledName, 0, 0, &status);
+  char *      unmangled = abi::__cxa_demangle(mangledName, ITK_NULLPTR, ITK_NULLPTR, &status);
   name = unmangled;
   free(unmangled);
 #else
@@ -66,7 +66,7 @@ template<typename T> void CheckFixedArrayTraits(const T &t)
 #ifdef GCC_USEDEMANGLE
   char const *mangledName = typeid( t ).name();
   int         status;
-  char *      unmangled = abi::__cxa_demangle(mangledName, 0, 0, &status);
+  char *      unmangled = abi::__cxa_demangle(mangledName, ITK_NULLPTR, ITK_NULLPTR, &status);
   name = unmangled;
   free(unmangled);
 #else
