@@ -151,7 +151,7 @@ int itkSmartPointerTest(int, char* [] )
 
 
   // check test of null pointer
-  itkTestObject::Pointer q(NULL);
+  itkTestObject::Pointer q(SP_ITK_NULLPTR);
   std::cout << q;
 
   std::cout <<"first test" << std::endl;
@@ -161,6 +161,10 @@ int itkSmartPointerTest(int, char* [] )
     {
     return EXIT_FAILURE;
     }
+
+  // use argument dependent loop up for swap in itk namespace
+  swap(q,o1);
+
   }
   std::cout <<"end first test" << std::endl << std::endl;
   return EXIT_SUCCESS;
