@@ -23,6 +23,9 @@
 
 namespace itk
 {
+/** Create a helper GPU Kernel class for GPUDenseFiniteDifferenceImageFilter */
+itkGPUKernelClassMacro(GPUDenseFiniteDifferenceImageFilterKernel);
+
 /**
  * \class GPUDenseFiniteDifferenceImageFilter
  * This is the GPU version of DenseFiniteDifferenceImageFilter class.
@@ -46,13 +49,9 @@ namespace itk
  *
  * \ingroup ITKGPUFiniteDifference
  */
-
-/** Create a helper GPU Kernel class for GPUDenseFiniteDifferenceImageFilter */
-itkGPUKernelClassMacro(GPUDenseFiniteDifferenceImageFilterKernel);
-
-template< class TInputImage, class TOutputImage, class TParentImageFilter =
+template< typename TInputImage, typename TOutputImage, typename TParentImageFilter =
             DenseFiniteDifferenceImageFilter< TInputImage, TOutputImage > >
-class ITK_EXPORT GPUDenseFiniteDifferenceImageFilter :
+class GPUDenseFiniteDifferenceImageFilter :
   public GPUFiniteDifferenceImageFilter< TInputImage, TOutputImage, TParentImageFilter >
 {
 public:
@@ -86,14 +85,14 @@ public:
   typedef OutputImageType UpdateBufferType;
 
 #ifdef ITK_USE_CONCEPT_CHECKING
-  /** Begin concept checking */
+  // Begin concept checking
   itkConceptMacro( OutputTimesDoubleCheck,
                    ( Concept::MultiplyOperator< PixelType, double > ) );
   itkConceptMacro( OutputAdditiveOperatorsCheck,
                    ( Concept::AdditiveOperators< PixelType > ) );
   itkConceptMacro( InputConvertibleToOutputCheck,
                    ( Concept::Convertible< typename TInputImage::PixelType, PixelType > ) );
-  /** End concept checking */
+  // End concept checking
 #endif
 
   /** Get OpenCL Kernel source as a string, creates a GetOpenCLSource method */
