@@ -26,7 +26,7 @@ namespace itk
 namespace Accessor
 {
 /** \class AcosPixelAccessor
- * \brief Give access to the vcl_acos() function of a value
+ * \brief Give access to the std::acos() function of a value
  *
  * AcosPixelAccessor is templated over an internal type and an
  * external type representation. This class cast the input
@@ -51,15 +51,15 @@ public:
   typedef TInternalType InternalType;
 
   static inline void Set(TInternalType & output, const TExternalType & input)
-  { output = (TInternalType)vcl_acos( (double)input ); }
+  { output = (TInternalType)std::acos( (double)input ); }
 
   static inline TExternalType Get(const TInternalType & input)
-  { return (TExternalType)vcl_acos( (double)input ); }
+  { return (TExternalType)std::acos( (double)input ); }
 };
 } // end namespace Accessor
 
 /** \class AcosImageAdaptor
- * \brief Presents an image as being composed of the vcl_acos() of its pixels
+ * \brief Presents an image as being composed of the std::acos() of its pixels
  *
  * Additional casting is performed according to the input and output image
  * types following C++ default casting rules.
