@@ -27,7 +27,7 @@ namespace Accessor
 {
 /**
  * \class AtanPixelAccessor
- * \brief Give access to the vcl_atan() function of a value
+ * \brief Give access to the std::atan() function of a value
  *
  * AtanPixelAccessor is templated over an internal type and an
  * external type representation. This class cast the input
@@ -52,16 +52,16 @@ public:
   typedef TInternalType InternalType;
 
   static inline void Set(TInternalType & output, const TExternalType & input)
-  { output = (TInternalType)vcl_atan( (double)input ); }
+  { output = (TInternalType)std::atan( (double)input ); }
 
   static inline TExternalType Get(const TInternalType & input)
-  { return (TExternalType)vcl_atan( (double)input ); }
+  { return (TExternalType)std::atan( (double)input ); }
 };
 } // end namespace Accessor
 
 /**
  * \class AtanImageAdaptor
- * \brief Presents an image as being composed of the vcl_atan() of its pixels
+ * \brief Presents an image as being composed of the std::atan() of its pixels
  *
  * Additional casting is performed according to the input and output image
  * types following C++ default casting rules.
