@@ -187,10 +187,7 @@ public:
   virtual const RegionType & GetBufferedRegion() const;
 
   /** Allocate the image memory. Dimension and Size must be set a priori. */
-  inline void Allocate()
-  {
-    m_Image->Allocate();
-  }
+  virtual void Allocate(bool initialize = false) ITK_OVERRIDE;
 
   /** Restore the data object to its initial state. This means releasing
    * memory. */
@@ -316,8 +313,7 @@ public:
 
   virtual void SetRequestedRegionToLargestPossibleRegion();
 
-  virtual void PropagateRequestedRegion()
-  throw ( InvalidRequestedRegionError );
+  virtual void PropagateRequestedRegion();
 
   virtual void UpdateOutputData();
 
