@@ -26,7 +26,7 @@ namespace itk
 namespace Accessor
 {
 /** \class TanPixelAccessor
- * \brief Give access to the vcl_tan() function of a value
+ * \brief Give access to the std::tan() function of a value
  *
  * TanPixelAccessor is templated over an internal type and an
  * external type representation. This class cast the input
@@ -49,15 +49,15 @@ public:
   typedef TInternalType InternalType;
 
   static inline void Set(TInternalType & output, const TExternalType & input)
-  { output = (TInternalType)vcl_tan( (double)input ); }
+  { output = (TInternalType)std::tan( (double)input ); }
 
   static inline TExternalType Get(const TInternalType & input)
-  { return (TExternalType)vcl_tan( (double)input ); }
+  { return (TExternalType)std::tan( (double)input ); }
 };
 } // end namespace Accessor
 
 /** \class TanImageAdaptor
- * \brief Presents an image as being composed of the vcl_tan() of its pixels
+ * \brief Presents an image as being composed of the std::tan() of its pixels
  *
  * Additional casting is performed according to the input and output image
  * types following C++ default casting rules.
