@@ -30,18 +30,20 @@
 
 #include "itkBSplineInterpolateImageFunction.h"
 
+#include "makeRandomImageBsplineInterpolator.h"
+
 
   typedef double InputPixelType;
   typedef double CoordRepType;
 
-// Set up for 1D Images
+  // Set up for 1D Images
   enum { ImageDimension1D = 1 };
 
   typedef itk::Image< InputPixelType, ImageDimension1D >                 ImageType1D;
   typedef ImageType1D::Pointer                                           ImageTypePtr1D;
   typedef ImageType1D::SizeType                                          SizeType1D;
   typedef itk::BSplineInterpolateImageFunction<ImageType1D,CoordRepType> InterpolatorType1D;
-//  typedef InterpolatorType1D::IndexType                 IndexType1D;
+  //  typedef InterpolatorType1D::IndexType                 IndexType1D;
   typedef InterpolatorType1D::PointType                                  PointType1D;
   typedef InterpolatorType1D::ContinuousIndexType                        ContinuousIndexType1D;
 
@@ -54,7 +56,7 @@
   typedef ImageType2D::Pointer                                           ImageTypePtr2D;
   typedef ImageType2D::SizeType                                          SizeType2D;
   typedef itk::BSplineInterpolateImageFunction<ImageType2D,CoordRepType> InterpolatorType2D;
-//  typedef InterpolatorType2D::IndexType                 IndexType2D;
+  //  typedef InterpolatorType2D::IndexType                 IndexType2D;
   typedef InterpolatorType2D::PointType                                  PointType2D;
   typedef InterpolatorType2D::ContinuousIndexType                        ContinuousIndexType2D;
 
@@ -77,11 +79,9 @@
   typedef InterpolatorIntegerType3D::PointType                                  PointIntegerType3D;
   typedef InterpolatorIntegerType3D::ContinuousIndexType                        ContinuousIntegerIndexType3D;
 
-//  template <class TImage>
-//  void set3DInterpData(TImage::Pointer);
   void set3DDerivativeData(ImageType3D::Pointer);
 
-template<class TImage>
+template<typename TImage>
 void set3DInterpData(typename TImage::Pointer imgPtr)
 {
   SizeType3D size = {{80,40,30}};
@@ -114,7 +114,7 @@ void set3DInterpData(typename TImage::Pointer imgPtr)
  * Test a geometric point. Returns true if test has passed,
  * returns false otherwise
  */
-template <class TInterpolator, class PointType>
+template <typename TInterpolator, typename PointType>
 bool TestGeometricPoint(
 const TInterpolator * interp,
 const PointType& point,
@@ -154,7 +154,7 @@ double trueValue )
  * Test a continuous index. Returns true if test has passed,
  * returns false otherwise
  */
-template<class TInterpolator, class ContinuousIndexType>
+template<typename TInterpolator, typename ContinuousIndexType>
 bool TestContinuousIndex(
 const TInterpolator * interp,
 const ContinuousIndexType& index,
@@ -193,7 +193,7 @@ double trueValue )
  * Test a continuous index Derivative. Returns true if test has passed,
  * returns false otherwise
  */
-template<class TInterpolator, class ContinuousIndexType>
+template<typename TInterpolator, typename ContinuousIndexType>
 bool TestContinuousIndexDerivative(
 const TInterpolator * interp,
 const ContinuousIndexType& index,
@@ -259,7 +259,6 @@ int test1DCubicSpline()
 
   // Create and initialize the interpolator
   InterpolatorType1D::Pointer interp = InterpolatorType1D::New();
-//  interp->SetSplineOrder(1);
   interp->SetInputImage(image);
   interp->Print( std::cout );
 
@@ -276,7 +275,7 @@ int test1DCubicSpline()
   //    3) integer value
   //    4) outside image
 #define NPOINTS 5  // number of points
-  double darray1[NPOINTS] = {1.4, 8.9, 10.0, 40.0, -0.3};
+  itk::SpacePrecisionType darray1[NPOINTS] = {1.4, 8.9, 10.0, 40.0, -0.3};
   double truth[NPOINTS] = {334.41265437584, 18.158173426944, 4.0000, 0, 442.24157192006658};
   bool b_Inside[NPOINTS] = {true, true, true, false, true};
 
@@ -340,19 +339,16 @@ int test2DSpline()
     //    4) outside image
 #define NPOINTS2 4  // number of points
 
-    double darray1[NPOINTS2][2] = {{0.1, 0.2}, {3.4, 5.8}, {4.0, 6.0}, { 2.1, 8.0}};
+    itk::SpacePrecisionType darray1[NPOINTS2][2] = {{0.1, 0.2}, {3.4, 5.8}, {4.0, 6.0}, { 2.1, 8.0}};
     double truth[NPOINTS2][6] = {{154.5, 140.14, 151.86429192392, 151.650316034, 151.865916515, 151.882483111},
         { 0, 13.84, 22.688125812495, 22.411473093, 22.606968306, 22.908345604},
         { 36.2, 36.2, 36.2, 36.2, 36.2, 36.2 },
         {0, 0, 0,0,0,0}};
     bool b_Inside[NPOINTS2] = {true, true, true, false};
-   // double darray1[2];
 
     // an integer position inside the image
     for (int ii=0; ii < NPOINTS2; ii++)
       {
-     // darray1[0] = darray[ii][0];
-     // darray1[1] = darray[ii][1];
       cindex = ContinuousIndexType2D(&darray1[ii][0]);
       cindex[0] += startIndex[0];
       cindex[1] += startIndex[1];
@@ -409,7 +405,7 @@ int test3DSpline()
     //    4) outside image
 #define NPOINTS3 5  // number of points
 
-    double darray1[NPOINTS3][ImageDimension3D]
+    itk::SpacePrecisionType darray1[NPOINTS3][ImageDimension3D]
       = {{0.1, 20.1, 28.4}, {21.58, 34.5, 17.2}, {10, 20, 12}, {15, 20.2, 31}, {2, 0.3, -0.3}};
     double truth[NPOINTS3][4] = {{48.621593795, 48.651173138, 48.656914878, 48.662256571},
         {73.280126903, 73.280816965, 73.282780615, 73.285315943},
@@ -417,13 +413,10 @@ int test3DSpline()
         {0, 0, 0, 0},
         {  2.2545584407825165, 2.2722384004239382, 2.2533523347849744, 2.2516795363567588}};
     bool b_Inside[NPOINTS3] = {true, true, true, false, true};
-   // double darray1[2];
 
     // an integer position inside the image
     for (int ii=0; ii < NPOINTS3; ii++)
       {
-     // darray1[0] = darray[ii][0];
-     // darray1[1] = darray[ii][1];
       cindex = ContinuousIndexType3D(&darray1[ii][0]);
       passed = TestContinuousIndex<InterpolatorType3D, ContinuousIndexType3D >( interp, cindex, b_Inside[ii], truth[ii][splineOrder -2] );
 
@@ -449,8 +442,6 @@ int test3DSplineDerivative()
   set3DDerivativeData(image);
 
   /* Set origin and spacing of physical coordinates */
-//  double origin [] = { 0.5, 1.0, 1.333};
-//  double spacing[] = { 0.1, 0.5, 0.75  };
   double origin [] = { 0.0, 0.0, 0.0};
   double spacing[] = { 1,1,1  };
   image->SetOrigin(origin);
@@ -479,7 +470,7 @@ int test3DSplineDerivative()
     //    4) outside image
 #define NPOINTS4 4  // number of points
 
-    double darray1[NPOINTS4][ImageDimension3D] = {{25.3,26.8,24.5}, {21.0, 1.4, 0.6}, {18, 31, 10 }, { 4.3, 17.9, 42} };
+    itk::SpacePrecisionType darray1[NPOINTS4][ImageDimension3D] = {{25.3,26.8,24.5}, {21.0, 1.4, 0.6}, {18, 31, 10 }, { 4.3, 17.9, 42} };
     // Calculated Truth is: {19.4158,5,-24}, {0.9,5,71.6}, {-7.2, 5, 34}, {0,0,0}
     // TODO: Value near border is way off, is this an algorithm problem?  Also,
     //       Is error for 1st order splines in the expected range?
@@ -490,21 +481,12 @@ int test3DSplineDerivative()
       { {19.4164,5,-24}, {0.9,      4.9925,  94.5082}, {-7.2,     5.00044, 33.9976}, {0,0,0} },
       { {19.4223,5,-24}, {0.900157, 5.0544,  93.8607}, {-7.19929, 5.00189, 33.9879}, {0,0,0} }};
     bool b_Inside[NPOINTS4] = {true, true, true, false};
-   // double darray1[2];
 
     // an integer position inside the image
     for (int ii=0; ii < NPOINTS4; ii++)
       {
-     // darray1[0] = darray[ii][0];
-     // darray1[1] = darray[ii][1];
       cindex = ContinuousIndexType3D(&darray1[ii][0]);
       passed = TestContinuousIndexDerivative<InterpolatorType3D, ContinuousIndexType3D >( interp, cindex, b_Inside[ii], &truth[splineOrder - 1][ii][0] );
-
-      if( !passed ) flag += 1;
-
-//      interp->ConvertContinuousIndexToPoint( cindex, point );
-//      passed = TestGeometricPoint<InterpolatorType3D, PointType3D>( interp, point, b_Inside[ii], truth[ii][splineOrder -2]  );
-
       if( !passed ) flag += 1;
       }
     }  // end of splineOrder
@@ -551,19 +533,16 @@ int testInteger3DSpline()
 #define NPOINTS4b 4  // number of points
 
     // Note: the answers should be the same as for the test3DSpline
-    double darray1[NPOINTS4b][ImageDimension3D] = {{0.1, 20.1, 28.4}, {21.58, 34.5, 17.2 }, {10, 20, 12}, { 15, 20.2, 31}};
+    itk::SpacePrecisionType darray1[NPOINTS4b][ImageDimension3D] = {{0.1, 20.1, 28.4}, {21.58, 34.5, 17.2 }, {10, 20, 12}, { 15, 20.2, 31}};
     double truth[NPOINTS4b][4] = {{48.621593795, 48.651173138, 48.656914878, 48.662256571},
         { 73.280126903, 73.280816965, 73.282780615, 73.285315943},
         { 42.0, 42.0, 42.0, 42.0},
         {0,0,0,0}};
     bool b_Inside[NPOINTS4b] = {true, true, true, false};
-   // double darray1[2];
 
     // an integer position inside the image
     for (int ii=0; ii < NPOINTS4b; ii++)
       {
-     // darray1[0] = darray[ii][0];
-     // darray1[1] = darray[ii][1];
       cindex = ContinuousIntegerIndexType3D(&darray1[ii][0]);
       passed = TestContinuousIndex<InterpolatorIntegerType3D, ContinuousIntegerIndexType3D >( interp, cindex, b_Inside[ii], truth[ii][splineOrder -2] );
 
@@ -579,6 +558,45 @@ int testInteger3DSpline()
   return (flag);
 }
 
+//Test to verify that EvaluateDerivativeAtContinuousIndex and EvaluateValueAndDerivativeAtContinuousIndex
+//produce identical results.
+int testEvaluateValueAndDerivative(void)
+{
+  const unsigned int ImageDimension = 2;
+  typedef float                                  PixelType;
+  typedef   itk::Image<PixelType,ImageDimension> ImageType;
+  typedef itk::BSplineInterpolateImageFunction<ImageType,double, double> BSplineInterpolatorFunctionType;
+
+  const unsigned int SplineOrder = 3;
+  BSplineInterpolatorFunctionType::Pointer interpolator = makeRandomImageInterpolator<BSplineInterpolatorFunctionType>(SplineOrder);
+
+  /** Test the EvaluateDerivative and EvaluateValueAndDerivative functions **/
+  typedef BSplineInterpolatorFunctionType::ContinuousIndexType ContinuousIndexType;
+  ContinuousIndexType x;
+  x[0] = 15.1;
+  x[1] = 15.2;
+
+  typedef BSplineInterpolatorFunctionType::CovariantVectorType CovariantVectorType;
+  const CovariantVectorType dx_1 = interpolator->EvaluateDerivativeAtContinuousIndex( x );
+  CovariantVectorType dx_2;
+
+  BSplineInterpolatorFunctionType::OutputType value;
+  interpolator->EvaluateValueAndDerivativeAtContinuousIndex( x, value, dx_2 );
+
+  for( unsigned int i = 0; i < ImageDimension; ++i )
+    {
+    std::cout << std::scientific << value << std::endl;
+    std::cout << std::scientific << "EvaluateDerivative:         " << dx_1 << std::endl;
+    std::cout << std::scientific << "EvaluateValueAndDerivative: " << dx_2 << std::endl;
+    if( vnl_math_abs( dx_1[i] - dx_2[i] ) >  1e-5 )
+      {
+      std::cout << "[ERROR]" << dx_1[i] << " != " << dx_2[i] << std::endl;
+      return EXIT_FAILURE;
+      }
+    }
+  return EXIT_SUCCESS;
+}
+
 int
 itkBSplineInterpolateImageFunctionTest(
     int itkNotUsed(argc),
@@ -598,6 +616,8 @@ itkBSplineInterpolateImageFunctionTest(
 
   flag += testInteger3DSpline();
 
+  flag += testEvaluateValueAndDerivative();
+
   /* Return results of test */
   if (flag != 0) {
     std::cout << "*** " << flag << " tests failed" << std::endl;
@@ -711,7 +731,6 @@ void set3DDerivativeData(ImageType3D::Pointer imgPtr)
               value += 5.0*row1 + 7.0;
               value += -2.0*slice1*slice1 - 6.0* slice1 + 10.0;
               imgPtr->SetPixel(index, value);
-//              imgPtr->SetPixel(index, row);
           }
       }
   }
