@@ -280,7 +280,7 @@ int itkCentralDifferenceImageFunctionTest(int, char* [] )
   function->SetUseImageDirection( true );
   // first set to null and then reset image so that cached
   // info is recalculated
-  function->SetInputImage( NULL );
+  function->SetInputImage( ITK_NULLPTR );
   function->SetInputImage( image );
   OutputType directionOnDerivative = function->Evaluate( point );
   std::cout << "Point: " << point << " directionOnDerivative: "
@@ -316,7 +316,7 @@ int itkCentralDifferenceImageFunctionTest(int, char* [] )
   function->SetUseImageDirection( true );
   // first set to null and then reset image so that cached
   // info is recalculated
-  function->SetInputImage( NULL );
+  function->SetInputImage( ITK_NULLPTR );
   function->SetInputImage( image );
   OutputType directionOneNegDerivative = function->Evaluate( point );
   std::cout << "Point: " << point << " directionOneNegDerivative: " << directionOneNegDerivative << std::endl;
@@ -338,7 +338,7 @@ int itkCentralDifferenceImageFunctionTest(int, char* [] )
   function->SetUseImageDirection( true );
   // first set to null and then reset image so that cached
   // info is recalculated
-  function->SetInputImage( NULL );
+  function->SetInputImage( ITK_NULLPTR );
   function->SetInputImage( image );
   OutputType directionSwapDerivative = function->Evaluate( point );
   std::cout << "Point: " << point << " directionSwapDerivative: " << directionSwapDerivative << std::endl;
