@@ -39,10 +39,7 @@ int itkGaussianDerivativeImageFunctionTest(int, char* [] )
   region.SetSize( size );
 
   image->SetRegions( region );
-  image->Allocate();
-
-  ImageType::PixelType initialValue = 0;
-  image->FillBuffer( initialValue );
+  image->Allocate(true); // initialize buffer to zero
 
   // Fill the image with a straight line
   for(unsigned int i=0;i<50;i++)
@@ -120,7 +117,7 @@ int itkGaussianDerivativeImageFunctionTest(int, char* [] )
   std::cout << "Testing Evaluate() : ";
 
   if( (gradient_point[0] > 0.1)  ||
-      (vcl_fabs(gradient_point[1]+1.0)> 10e-4)
+      (std::fabs(gradient_point[1]+1.0)> 10e-4)
     )
     {
     std::cerr << "[FAILED]" << std::endl;
@@ -138,7 +135,7 @@ int itkGaussianDerivativeImageFunctionTest(int, char* [] )
   std::cout << "Testing Evaluate() : ";
 
   if( (gradient_point[0] > 0.1)  ||
-      (vcl_fabs(gradient_point[1]-1.0)> 10e-4)
+      (std::fabs(gradient_point[1]-1.0)> 10e-4)
     )
     {
     std::cerr << "[FAILED]" << std::endl;
