@@ -38,8 +38,8 @@ namespace itk
  * \sa TransformMeshFilter
  * \ingroup ITKMesh
  */
-template< class TInputMesh, class TOutputMesh, class TDisplacementField >
-class ITK_EXPORT WarpMeshFilter:
+template< typename TInputMesh, typename TOutputMesh, typename TDisplacementField >
+class WarpMeshFilter:
   public MeshToMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
