@@ -28,7 +28,6 @@ int itkImageToParametricSpaceFilterTest(int, char* [] )
   // Declare the type for the images
   typedef itk::Image<ImagePixelType,2>        ImageType;
   typedef ImageType::Pointer                  ImagePointer;
-  typedef ImageType::IndexType                IndexType;
 
   // Make the Mesh PointData type be an Image Index.
   typedef itk::Point<float,2>                 MeshPixelType;
@@ -36,9 +35,6 @@ int itkImageToParametricSpaceFilterTest(int, char* [] )
   // Declare the types of the Mesh
   typedef itk::Mesh<MeshPixelType>  MeshType;
 
-  // Declare the type for PointsContainer
-  typedef MeshType::PointsContainer     PointsContainerType;
-
   // Declare the type for PointsContainerPointer
   typedef MeshType::PointsContainerPointer
                                         PointsContainerPointer;
