@@ -76,7 +76,7 @@ public:
 protected:
   QuadEdgeMeshTopologyChecker();
   ~QuadEdgeMeshTopologyChecker(){}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   QuadEdgeMeshTopologyChecker(const Self &); //purposely not implemented
