@@ -135,14 +135,14 @@ public:
    * Note: For this class, this will always return false. -GH
    */
   bool IsEvaluableAt(const PointType & point,
-                     unsigned int depth = 0, char *name = NULL) const;
+                     unsigned int depth = 0, char *name = ITK_NULLPTR) const;
 
   /** Returns the value of the Contour at that point.
    *  Currently this function returns a binary value,
    *  but it might want to return a degree of membership
    *  in case of fuzzy Contours. */
   bool ValueAt(const PointType & point, double & value,
-               unsigned int depth = 0, char *name = NULL) const;
+               unsigned int depth = 0, char *name = ITK_NULLPTR) const;
 
   /** Returns true if the point is inside the Contour, false otherwise. */
   bool IsInside(const PointType & point,
