@@ -67,7 +67,7 @@ public:
 protected:
   SpatialObjectDuplicator();
   virtual ~SpatialObjectDuplicator() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   void CopyObject(const InternalSpatialObjectType *source,
                   InternalSpatialObjectType *destination);
