@@ -95,6 +95,19 @@ int itkBoxSpatialObjectTest( int argc, char *argv[] )
     std::cout << "Instead of [29 59 29 59]" << std::endl;
     return EXIT_FAILURE;
     }
+
+  BoxType::BoundingBoxType * boundingBox2 = box2->GetBoundingBox();
+  if(     (boundingBox2->GetBounds()[0] != 50)
+      ||  (boundingBox2->GetBounds()[1] != 80)
+      ||  (boundingBox2->GetBounds()[2] != 50)
+      ||  (boundingBox2->GetBounds()[3] != 80) )
+    {
+    std::cout << "[FAILED] Test returned" << std::endl;
+    std::cout << box2->GetBoundingBox()->GetBounds() << std::endl;
+    std::cout << "Instead of [50 80 50 80]" << std::endl;
+    return EXIT_FAILURE;
+    }
+
   std::cout << "[PASSED]" << std::endl;
 
   // Point consistency
