@@ -30,18 +30,18 @@ namespace itk
  *
  * \ingroup ITKTransform
  */
-template< class TScalarType,         // Data type for scalars (float or double)
+template< typename TScalar,         // Data type for scalars (float or double)
           unsigned int NDimensions = 3 >
 // Number of dimensions
-class ITK_EXPORT ThinPlateSplineKernelTransform:
-  public KernelTransform<   TScalarType, NDimensions >
+class ThinPlateSplineKernelTransform:
+  public KernelTransform< TScalar, NDimensions >
 {
 public:
   /** Standard class typedefs. */
-  typedef ThinPlateSplineKernelTransform                 Self;
-  typedef KernelTransform<    TScalarType, NDimensions > Superclass;
-  typedef SmartPointer< Self >                           Pointer;
-  typedef SmartPointer< const Self >                     ConstPointer;
+  typedef ThinPlateSplineKernelTransform          Self;
+  typedef KernelTransform< TScalar, NDimensions > Superclass;
+  typedef SmartPointer< Self >                    Pointer;
+  typedef SmartPointer< const Self >              ConstPointer;
 
   /** New macro for creation of through a Smart Pointer */
   itkNewMacro(Self);
