@@ -192,7 +192,6 @@ public:
   {
     itkExceptionMacro( "TransformVector(const InputVectorType &)"
                        "is unimplemented for " << this->GetNameOfClass() );
-    return OutputVectorType();
   }
 
   /** Method to transform a vector at a given location.
@@ -208,7 +207,6 @@ public:
   {
     itkExceptionMacro( "TransformVector( const InputVnlVectorType & ) is "
                        "unimplemented for " << this->GetNameOfClass() );
-    return OutputVnlVectorType();
   }
 
   /** Method to transform a vnl_vector, at a point.
@@ -225,7 +223,6 @@ public:
   {
     itkExceptionMacro( "TransformVector( const InputVectorPixelType & ) is "
                        "unimplemented for " << this->GetNameOfClass() );
-    return OutputVectorPixelType();
   }
 
   /** Method to transform a vector stored in a VectorImage, at a point.
@@ -241,7 +238,6 @@ public:
   {
     itkExceptionMacro( "TransformCovariantVector( const InputCovariantVectorType & ) is "
                        "unimplemented for " << this->GetNameOfClass() );
-    return OutputCovariantVectorType();
   }
   /** Method to transform a CovariantVector, using a point. Global transforms
    * can ignore the \c point parameter. Local transforms (e.g. deformation
@@ -259,7 +255,6 @@ public:
   {
     itkExceptionMacro( "TransformCovariantVector(const InputVectorPixelType &)"
                        "is unimplemented for " << this->GetNameOfClass() );
-    return OutputVectorPixelType();
   }
 
   /** Method to transform a CovariantVector, using a point. Global transforms
@@ -279,7 +274,6 @@ public:
     itkExceptionMacro(
       "TransformDiffusionTensor3D( const InputDiffusionTensor3DType & ) is "
       "unimplemented for " << this->GetNameOfClass() );
-    return OutputDiffusionTensor3DType();
   }
 
   /** Method to transform a diffusion tensor at a point. Global transforms
@@ -298,7 +292,6 @@ public:
     itkExceptionMacro(
       "TransformDiffusionTensor( const InputVectorPixelType & ) is "
       "unimplemented for " << this->GetNameOfClass() );
-    return OutputVectorPixelType();
   }
 
   virtual OutputVectorPixelType TransformDiffusionTensor3D(
@@ -321,7 +314,6 @@ public:
     itkExceptionMacro(
       "TransformSymmetricSecondRankTensor( const InputSymmetricSecondRankTensorType & ) is "
       "unimplemented for " << this->GetNameOfClass() );
-    return OutputSymmetricSecondRankTensorType();
   }
 
   /** Method to transform a ssr tensor stored in a VectorImage */
@@ -331,7 +323,6 @@ public:
     itkExceptionMacro(
       "TransformSymmetricSecondRankTensor( const InputVectorPixelType & ) is "
       "unimplemented for " << this->GetNameOfClass() );
-    return OutputVectorPixelType();
   }
 
   /** Method to transform a diffusion tensor stored in a VectorImage, at
@@ -429,7 +420,7 @@ public:
    */
   virtual InverseTransformBasePointer GetInverseTransform() const
   {
-    return NULL;
+    return ITK_NULLPTR;
   }
 
   /** Generate a platform independent name */
@@ -505,12 +496,12 @@ public:
    *  will most likely occur during multi-threading.
    *  To avoid repeatitive memory allocation, pass in 'jacobian' with its size
    *  already set. */
-  virtual void ComputeJacobianWithRespectToParameters(const InputPointType  & itkNotUsed(p), JacobianType & itkNotUsed(jacobian) ) const
+  virtual void ComputeJacobianWithRespectToParameters(const InputPointType  & itkNotUsed(p), JacobianType & itkNotUsed(jacobian) ) const = 0;
+
+  virtual void ComputeJacobianWithRespectToParametersCachedTemporaries(const InputPointType  & p, JacobianType & jacobian, JacobianType & itkNotUsed(jacobianWithRespectToPosition) ) const
   {
-    itkExceptionMacro(
-      "ComputeJacobianWithRespectToParamters( InputPointType, JacobianType"
-      " is unimplemented for " << this->GetNameOfClass() );
-    return;
+    //NOTE: default implementation is not optimized, and just falls back to original methods.
+    this->ComputeJacobianWithRespectToParameters(p, jacobian);
   }
 
 
@@ -524,7 +515,6 @@ public:
     itkExceptionMacro(
       "ComputeJacobianWithRespectToPosition( InputPointType, JacobianType"
       " is unimplemented for " << this->GetNameOfClass() );
-    return;
   }
 
 
