@@ -41,7 +41,7 @@ int itkIdentityTransformTest(int, char *[] )
   r = transform->TransformPoint( p );
   for( unsigned int i = 0; i < N; i++ )
     {
-    if( vcl_fabs( p[i] - r[i] ) > epsilon )
+    if( std::fabs( p[i] - r[i] ) > epsilon )
       {
       Ok = false;
       break;
@@ -67,7 +67,7 @@ int itkIdentityTransformTest(int, char *[] )
   vout = transform->TransformVector( vin );
   for( unsigned int i = 0; i < N; i++ )
     {
-    if( vcl_fabs( vout[i] - vin[i] ) > epsilon )
+    if( std::fabs( vout[i] - vin[i] ) > epsilon )
       {
       Ok = false;
       break;
@@ -93,7 +93,7 @@ int itkIdentityTransformTest(int, char *[] )
   vnlout = transform->TransformVector( vnlin );
   for( unsigned int i = 0; i < N; i++ )
     {
-    if( vcl_fabs( vnlout[i] - vnlin[i] ) > epsilon )
+    if( std::fabs( vnlout[i] - vnlin[i] ) > epsilon )
       {
       Ok = false;
       break;
@@ -119,7 +119,7 @@ int itkIdentityTransformTest(int, char *[] )
   vcout = transform->TransformCovariantVector( vcin );
   for( unsigned int i = 0; i < N; i++ )
     {
-    if( vcl_fabs( vcout[i] - vcin[i] ) > epsilon )
+    if( std::fabs( vcout[i] - vcin[i] ) > epsilon )
       {
       Ok = false;
       break;
