@@ -46,7 +46,7 @@ int itkScaleTransformTest(int ,char * [] )
     std::cout << std::endl;
     for(unsigned int i=0; i<N; i++)
     {
-      if( vcl_fabs( scale[i] - 1.0 ) > epsilon )
+      if( std::fabs( scale[i] - 1.0 ) > epsilon )
       {
         Ok = false;
         break;
@@ -84,7 +84,7 @@ int itkScaleTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( vcl_fabs( scale[i] - iscale[i] ) > epsilon )
+      if( std::fabs( scale[i] - iscale[i] ) > epsilon )
       {
         Ok = false;
         break;
@@ -109,7 +109,7 @@ int itkScaleTransformTest(int ,char * [] )
       r = scaleTransform->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;
@@ -141,7 +141,7 @@ int itkScaleTransformTest(int ,char * [] )
       r = scaleTransform->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( vcl_fabs( q[i]- r[i] ) > epsilon )
+        if( std::fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;
@@ -172,7 +172,7 @@ int itkScaleTransformTest(int ,char * [] )
       r = scaleTransform->TransformCovariantVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( vcl_fabs( q[i]- r[i] ) > epsilon )
+        if( std::fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;
@@ -205,7 +205,7 @@ int itkScaleTransformTest(int ,char * [] )
       r = scaleTransform->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;
