@@ -46,15 +46,6 @@ int itkSimilarity3DTransformTest(int, char * [] )
   //  Vector type
   typedef    TransformType::InputVectorType VectorType;
 
-  //  Point type
-  typedef    TransformType::InputPointType PointType;
-
-  //  Covariant Vector type
-  typedef    TransformType::InputCovariantVectorType CovariantVectorType;
-
-  //  VnlVector type
-  typedef    TransformType::InputVnlVectorType VnlVectorType;
-
   //  Parameters type
   typedef    TransformType::ParametersType ParametersType;
 
@@ -68,7 +59,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     std::cout << "Test default constructor... ";
 
     TransformType::Pointer transform = TransformType::New();
-    if( vcl_fabs(transform->GetScale() - 1.0) >
+    if( std::fabs(transform->GetScale() - 1.0) >
         itk::NumericTraits<TransformType::ScaleType>::min() )
       {
       std::cout << "Error: Scale: Expected 1.0, got "
@@ -79,7 +70,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     // SetIdentity supposed to reset scale as well.
     transform->SetScale(2.0);
     transform->SetIdentity();
-    if( vcl_fabs(transform->GetScale() - 1.0) >
+    if( std::fabs(transform->GetScale() - 1.0) >
         itk::NumericTraits<TransformType::ScaleType>::min() )
       {
       std::cout << "Error: Scale: Expected 1.0 after SetIdentity, got "
@@ -90,7 +81,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     VectorType axis(1.5);
 
-    ValueType angle = 120.0 * vcl_atan(1.0) / 45.0;
+    ValueType angle = 120.0 * std::atan(1.0) / 45.0;
 
     VersorType versor;
     versor.Set( axis, angle );
@@ -131,7 +122,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     itk::Vector<double, 3> axis(1);
 
-    const double angle = (vcl_atan(1.0) / 45.0) * 120.0; // turn 120 degrees
+    const double angle = (std::atan(1.0) / 45.0) * 120.0; // turn 120 degrees
 
     // this rotation will permute the axis x->y, y->z, z->x
     rotation->SetRotation( axis, angle );
@@ -141,7 +132,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     std::cout << offset << std::endl;
     for( unsigned int i = 0; i < 3; i++ )
       {
-      if( vcl_fabs( offset[i] - 0.0 ) > epsilon )
+      if( std::fabs( offset[i] - 0.0 ) > epsilon )
         {
         Ok = false;
         break;
@@ -168,7 +159,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
       r = rotation->TransformPoint( p );
       for( unsigned int i = 0; i < 3; i++ )
         {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
           {
           Ok = false;
           break;
@@ -198,7 +189,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
       r = rotation->TransformVector( p );
       for( unsigned int i = 0; i < 3; i++ )
         {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
           {
           Ok = false;
           break;
@@ -227,7 +218,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
       r = rotation->TransformCovariantVector( p );
       for( unsigned int i = 0; i < 3; i++ )
         {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
           {
           Ok = false;
           break;
@@ -260,7 +251,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
       r = rotation->TransformVector( p );
       for( unsigned int i = 0; i < 3; i++ )
         {
-        if( vcl_fabs( q[i] - r[i] ) > epsilon )
+        if( std::fabs( q[i] - r[i] ) > epsilon )
           {
           Ok = false;
           break;
@@ -287,7 +278,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     itk::Vector<double, 3> axis(1);
 
-    const double angle = (vcl_atan(1.0) / 45.0) * 30.0; // turn 30 degrees
+    const double angle = (std::atan(1.0) / 45.0) * 30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -302,7 +293,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     transformedPoint = transform->TransformPoint( center );
     for( unsigned int i = 0; i < 3; i++ )
       {
-      if( vcl_fabs( center[i] - transformedPoint[i] ) > epsilon )
+      if( std::fabs( center[i] - transformedPoint[i] ) > epsilon )
         {
         Ok = false;
         break;
@@ -340,7 +331,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     const double tolerance = 1e-8;
     for( unsigned int p = 0; p < np; p++ )
       {
-      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( std::fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cout << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -413,7 +404,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     itk::Vector<double, 3> axis(1);
 
-    const double angle = (vcl_atan(1.0) / 45.0) * 30.0; // turn 30 degrees
+    const double angle = (std::atan(1.0) / 45.0) * 30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -445,7 +436,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     const double tolerance = 1e-8;
     for( unsigned int p = 0; p < np; p++ )
       {
-      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( std::fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cout << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -460,7 +451,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     itk::Vector<double, 3> axis(1);
 
-    const double angle = (vcl_atan(1.0) / 45.0) * 30.0; // turn 30 degrees
+    const double angle = (std::atan(1.0) / 45.0) * 30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -486,7 +477,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     const double tolerance = 1e-8;
 
-    if( vcl_fabs( rscale - scale ) > tolerance )
+    if( std::fabs( rscale - scale ) > tolerance )
       {
       std::cout << "Error in Set/Get Scale() " << std::endl;
       return EXIT_FAILURE;
@@ -510,7 +501,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     ParametersType parameters2 = transform->GetParameters();
     for( unsigned int p = 0; p < np; p++ )
       {
-      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( std::fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cout << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -572,10 +563,10 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     double a = 1.0 / 180.0 * vnl_math::pi;
     double s = 0.5;
-    matrix[0][0] =        vcl_cos( a ) * s;
-    matrix[0][1] = -1.0 * vcl_sin( a ) * s;
-    matrix[1][0] =        vcl_sin( a ) * s;
-    matrix[1][1] =        vcl_cos( a ) * s;
+    matrix[0][0] =        std::cos( a ) * s;
+    matrix[0][1] = -1.0 * std::sin( a ) * s;
+    matrix[1][0] =        std::sin( a ) * s;
+    matrix[1][1] =        std::cos( a ) * s;
     matrix[2][2] =                   s;
 
     Ok = true;
@@ -608,7 +599,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
 
     ParametersType e( t->GetNumberOfParameters() );
     e.Fill( 0.0 );
-    e[2] = vcl_sin(0.5 * a);
+    e[2] = std::sin(0.5 * a);
     e[6] = 0.5;
 
     t = TransformType::New();
@@ -622,7 +613,7 @@ int itkSimilarity3DTransformTest(int, char * [] )
     ParametersType p = t2->GetParameters();
     for( unsigned int k = 0; k < e.GetSize(); k++ )
       {
-      if( vcl_fabs( e[k] - p[k] ) > epsilon )
+      if( std::fabs( e[k] - p[k] ) > epsilon )
         {
         std::cout << " [ FAILED ] " << std::endl;
         std::cout << "Expected parameters: " << e << std::endl;
