@@ -214,7 +214,7 @@ public:
    * so it's safe to return a null value. */
   virtual void * GetGlobalDataPointer() const
   {
-    return 0;
+    return ITK_NULLPTR;
   }
 
   /** Does nothing.  No global data is used in this class of equations.   */
