@@ -103,8 +103,8 @@ namespace itk
  * \wikiexample{Smoothing/AntiAliasBinaryImageFilter,Anti alias a binary image}
  * \endwiki
  */
-template< class TInputImage, class TOutputImage >
-class ITK_EXPORT AntiAliasBinaryImageFilter:
+template< typename TInputImage, typename TOutputImage >
+class AntiAliasBinaryImageFilter:
   public SparseFieldLevelSetImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -152,12 +152,12 @@ public:
   }
 
 #ifdef ITK_USE_CONCEPT_CHECKING
-  /** Begin concept checking */
+  // Begin concept checking
   itkConceptMacro( DoubleConvertibleToOutputCheck,
                    ( Concept::Convertible< double, typename TOutputImage::PixelType > ) );
   itkConceptMacro( InputOStreamWritableCheck,
                    ( Concept::OStreamWritable< typename TInputImage::PixelType > ) );
-  /** End concept checking */
+  // End concept checking
 #endif
 
 protected:
