@@ -20,9 +20,15 @@
 #include "vnl/vnl_math.h"
 
 #include "itkCompositeValleyFunction.h"
+#include "itkStdStreamStateSave.h"
 
 int itkCompositeValleyFunctionTest(int , char* [] )
 {
+// Save the format stream variables for std::cout
+// They will be restored when coutState goes out of scope
+// scope.
+  itk::StdStreamStateSave coutState(std::cout);
+
   itk::Array< double > means(2);
   itk::Array< double > sigmas(2);
 
@@ -47,6 +53,7 @@ int itkCompositeValleyFunctionTest(int , char* [] )
 
   std::cout.setf(std::ios::scientific);
   std::cout.precision(12);
+
   double interval1 = function.GetInterval();
   double interval2 =
     ( function.GetUpperBound() - function.GetLowerBound() )
@@ -72,6 +79,7 @@ int itkCompositeValleyFunctionTest(int , char* [] )
     {
     std::cout << "diff = " << vnl_math_abs(value1 - value2) << std::endl;
     std::cout << "Test fails: operator()" << std::endl;
+
     return EXIT_FAILURE;
     }
 
