@@ -206,7 +206,7 @@ int itkParametricBlindLeastSquaresDeconvolutionImageFilterTest(int argc, char* a
     }
 
   KernelSourceType::ParametersValueType expectedSigmaX = 2.90243;
-  if ( vcl_abs( kernelSource->GetParameters()[0] - expectedSigmaX ) > 1e-5 )
+  if ( std::abs( kernelSource->GetParameters()[0] - expectedSigmaX ) > 1e-5 )
     {
     std::cerr << "Kernel parameter[0] should have been " << expectedSigmaX
               << ", was " << kernelSource->GetParameters()[0] << "."
@@ -215,7 +215,7 @@ int itkParametricBlindLeastSquaresDeconvolutionImageFilterTest(int argc, char* a
     }
 
   KernelSourceType::ParametersValueType expectedSigmaY = 2.90597;
-  if ( vcl_abs( kernelSource->GetParameters()[1] - expectedSigmaY ) > 1e-5 )
+  if ( std::abs( kernelSource->GetParameters()[1] - expectedSigmaY ) > 1e-5 )
     {
     std::cerr << "Kernel parameter[1] should have been " << expectedSigmaY
               << ", was " << kernelSource->GetParameters()[0] << "."
