@@ -96,7 +96,7 @@ int itkRichardsonLucyDeconvolutionImageFilterTest(int argc, char* argv[])
 
   const DeconvolutionFilterType::InternalImageType * estimate =
     deconvolutionFilter->GetCurrentEstimate();
-  if ( estimate != NULL )
+  if ( estimate != ITK_NULLPTR )
     {
     std::cerr << "Estimate should be NULL after the last iteration." << std::endl;
     return EXIT_FAILURE;
