@@ -20,6 +20,8 @@
 
 #include "itkImageToImageFilter.h"
 #include "itkVectorInterpolateImageFunction.h"
+#include "itkVectorLinearInterpolateImageFunction.h"
+#include "itkSimpleFastMutexLock.h"
 
 namespace itk
 {
@@ -73,6 +75,8 @@ public:
   typedef typename VectorType::ComponentType                        RealType;
   typedef Image<RealType, ImageDimension>                           RealImageType;
   typedef VectorInterpolateImageFunction<InputFieldType, RealType>  InterpolatorType;
+  typedef VectorLinearInterpolateImageFunction <InputFieldType, RealType>
+                                                                    DefaultInterpolatorType;
 
   /** Get the interpolator. */
   itkGetModifiableObjectMacro( Interpolator, InterpolatorType );
@@ -169,6 +173,7 @@ private:
   SpacingType                                       m_DisplacementFieldSpacing;
   bool                                              m_DoThreadedEstimateInverse;
   bool                                              m_EnforceBoundaryCondition;
+  SimpleFastMutexLock                               m_Mutex;
 
 };
 
