@@ -33,7 +33,7 @@ SimpleSignedDistance( const TPoint & p )
     {
     accum += static_cast< double >( vnl_math_sqr( p[j] - center[j] ) );
     }
-  accum = vcl_sqrt( accum );
+  accum = std::sqrt( accum );
   if (vnl_math_abs(accum - radius) > 1)
     {
     if((accum - radius) > 0)
@@ -115,7 +115,6 @@ int FastChamferDistanceImageFilterTest( unsigned int iPositive,
   filter->Print(std::cout);
 
   //Create NarrowBand
-  typedef typename ChamferFilterType::BandNodeType    BandNodeType;
   typedef typename ChamferFilterType::NarrowBandType  NarrowBandType;
 
   typename NarrowBandType::Pointer band = NarrowBandType::New();
