@@ -187,7 +187,7 @@ int itkFastMarchingTest2(int, char* [] )
         {
           distance += tempIndex[j] * tempIndex[j];
         }
-      distance = vcl_sqrt( distance );
+      distance = std::sqrt( distance );
 
       if (distance < itk::NumericTraits<double>::epsilon() )
         {
