@@ -194,8 +194,7 @@ public:
    * pipeline execution model.
    *
    * \sa ImageToImageFilter::GenerateInputRequestedRegion() */
-  virtual void GenerateInputRequestedRegion()
-  throw( InvalidRequestedRegionError );
+  virtual void GenerateInputRequestedRegion();
 
   /** Set the derivative weights according to the spacing of the input image
       (1/spacing). Use this option if you want to calculate the gradient in the
@@ -309,7 +308,7 @@ protected:
         }
       accum += sum;
       }
-    return vcl_sqrt(accum);
+    return std::sqrt(accum);
   }
 
   TRealType EvaluateAtNeighborhood3D(const ConstNeighborhoodIteratorType & it) const
