@@ -243,7 +243,7 @@ int itkExpandImageFilterTest(int, char* [] )
     {
     testPassed = false;
     std::cout << "Setting Input to NULL" << std::endl;
-    expander->SetInput( NULL );
+    expander->SetInput( ITK_NULLPTR );
     expander->Update();
     }
   catch( itk::ExceptionObject& err )
@@ -265,7 +265,7 @@ int itkExpandImageFilterTest(int, char* [] )
     {
     testPassed = false;
     std::cout << "Setting Interpolator to NULL" << std::endl;
-    expander->SetInterpolator( NULL );
+    expander->SetInterpolator( ITK_NULLPTR );
     expander->Update();
     }
   catch( itk::ExceptionObject& err )
