@@ -350,7 +350,7 @@ int itkWarpVectorImageFilterTest(int, char* [] )
     {
     std::cout << "Setting interpolator to NULL" << std::endl;
     testPassed = false;
-    warper->SetInterpolator( NULL );
+    warper->SetInterpolator( ITK_NULLPTR );
     warper->Update();
     }
   catch( itk::ExceptionObject& err )
