@@ -48,7 +48,7 @@ public:
 
   inline TOutput operator()(const TInput & A) const
   {
-    return static_cast< TOutput >( vcl_cos( static_cast< double >( A ) ) );
+    return static_cast< TOutput >( std::cos( static_cast< double >( A ) ) );
   }
 };
 }
@@ -62,8 +62,8 @@ public:
  * each pixel does the following:
  *
  * \li cast the pixel value to \c double,
- * \li apply the \c vcl_cos() function to the \c double value,
- * \li cast the \c double value resulting from \c vcl_cos() to the pixel type of the output image,
+ * \li apply the \c std::cos() function to the \c double value,
+ * \li cast the \c double value resulting from \c std::cos() to the pixel type of the output image,
  * \li store the cast value into the output image.
  *
  * The filter expects both images to have the same dimension (e.g. both
