@@ -54,7 +54,7 @@ public:
 
   inline TOutput operator()(const TInput & A) const
   {
-    return static_cast< TOutput >( vcl_exp( -1.0 * A.GetNorm() ) );
+    return static_cast< TOutput >( std::exp( -1.0 * A.GetNorm() ) );
   }
 };
 }
