@@ -78,7 +78,7 @@ public:
 protected:
   HistogramAlgorithmBase();
   virtual ~HistogramAlgorithmBase() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   virtual void Compute() = 0;
 
