@@ -202,7 +202,7 @@ public:
 protected:
   ImageMomentsCalculator();
   virtual ~ImageMomentsCalculator();
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   ImageMomentsCalculator(const Self &); //purposely not implemented
