@@ -362,7 +362,7 @@ public:
 
 protected:
   LabelObject();
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   LabelObject(const Self &);    //purposely not implemented
