@@ -521,7 +521,7 @@ public:
 
     // copy the data of the current type if possible
     const Self *src = dynamic_cast< const Self * >( lo );
-    if ( src == NULL )
+    if ( src == ITK_NULLPTR )
       {
       return;
       }
