@@ -115,12 +115,12 @@ public:
   virtual void Modified() const;
 
   /** define values used to determine which algorithm to use */
-  enum {
+  enum AlgorithmType {
     BASIC = 0,
     HISTO = 1,
     ANCHOR = 2,
     VHGW = 3
-    } AlgorithmChoice;
+  };
 
   /** A safe border is added to input image to avoid borders effects
    * and remove it once the closing is done */
