@@ -58,8 +58,8 @@ OpeningByReconstructionImageFilter, ClosingByReconstructionImageFilter, Reconstr
  * \ingroup ITKMathematicalMorphology
  */
 
-template< class TInputImage, class TOutputImage >
-class ITK_EXPORT ReconstructionByErosionImageFilter:
+template< typename TInputImage, typename TOutputImage >
+class ReconstructionByErosionImageFilter:
   public ReconstructionImageFilter< TInputImage, TOutputImage, std::less< typename TOutputImage::PixelType > >
 {
 public:
