@@ -82,16 +82,16 @@ public:
   // Functions inherited from Path
 
   /** Evaluate the chaincode for the offset at the specified path-position. */
-  virtual OutputType Evaluate(const InputType & input) const;
+  virtual OutputType Evaluate(const InputType & input) const ITK_OVERRIDE;
 
   /** Like Evaluate(), but returns the index at the specified path-position. */
-  virtual IndexType EvaluateToIndex(const InputType & input) const;
+  virtual IndexType EvaluateToIndex(const InputType & input) const ITK_OVERRIDE;
 
   /** Increment the input variable passed by reference and return the offset
    * stored at the previous path-position.  If the chaincode is unable to be
    * incremented, input is not changed and an offset of zero is returned, which
    * may be used to check for the end of the chain code. */
-  virtual OffsetType IncrementInput(InputType & input) const;
+  virtual OffsetType IncrementInput(InputType & input) const ITK_OVERRIDE;
 
   // Functions specific to ChainCodePath and its descendents
 
@@ -99,7 +99,7 @@ public:
   itkNewMacro(Self);
 
   /** How many steps in the chaincode? */
-  inline ChainCodeSizeType NumberOfSteps() const { return m_Chain2D.size(); }
+  virtual inline ChainCodeSizeType NumberOfSteps() const ITK_OVERRIDE { return m_Chain2D.size(); }
 
   /** Insert a new step into the chaincode at a specified position */
   inline void InsertStep(InputType position, int encodedStep)
@@ -108,7 +108,7 @@ public:
     this->Modified();
   }
 
-  inline void InsertStep(InputType position, OffsetType step)
+  virtual inline void InsertStep(InputType position, OffsetType step) ITK_OVERRIDE
   {
     m_Chain2D.insert( m_Chain2D.begin() + position, EncodeOffset(step) );
     this->Modified();
@@ -121,14 +121,14 @@ public:
     this->Modified();
   }
 
-  inline void ChangeStep(InputType position, OffsetType step)
+  virtual inline void ChangeStep(InputType position, OffsetType step) ITK_OVERRIDE
   {
     m_Chain2D[position] = EncodeOffset(step);
     this->Modified();
   }
 
   /** Remove all steps from the chain code */
-  virtual inline void Clear()
+  virtual inline void Clear() ITK_OVERRIDE
   {
     m_Chain2D.clear();
     this->Modified();
@@ -139,7 +139,7 @@ public:
 protected:
   ChainCodePath2D();
   ~ChainCodePath2D();
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Encode and Decode between an offset and a Freeman code */
   inline int EncodeOffset(OffsetType step) const
