@@ -138,7 +138,7 @@ public:
 
     if ((isstream >> value).fail() || !(isstream >> std::ws).eof())
     {
-      return vcl_numeric_limits<TData>::quiet_NaN();
+      return std::numeric_limits<TData>::quiet_NaN();
     }
     else
     {
@@ -167,7 +167,7 @@ protected:
   CSVFileReaderBase();
   virtual ~CSVFileReaderBase() {}
   /** Print method */
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Check that all essential components are present and plugged in. */
   void PrepareForParsing();
