@@ -18,6 +18,7 @@
 #ifndef __itkDCMTKFileReader_h
 
 #define __itkDCMTKFileReader_h
+#include "ITKIODCMTKExport.h"
 #include <stack>
 #include <vector>
 #include "itkByteSwapper.h"
@@ -56,9 +57,9 @@ class DcmDictEntry;
 
 namespace itk
 {
-class DCMTKSequence;
+class ITKIODCMTK_EXPORT DCMTKSequence;
 
-class DCMTKItem
+class ITKIODCMTK_EXPORT DCMTKItem
 {
 public:
   DCMTKItem() : m_DcmItem(0)
@@ -74,7 +75,7 @@ private:
   DcmItem *m_DcmItem;
 };
 
-class DCMTKSequence
+class ITKIODCMTK_EXPORT DCMTKSequence
 {
 public:
   DCMTKSequence() : m_DcmSequenceOfItems(0) {}
@@ -231,7 +232,7 @@ private:
   DcmSequenceOfItems *m_DcmSequenceOfItems;
 };
 
-class DCMTKFileReader
+class ITKIODCMTK_EXPORT DCMTKFileReader
 {
 public:
   typedef DCMTKFileReader Self;
