@@ -17,6 +17,7 @@
  *=========================================================================*/
 #ifndef __itkDCMTKImageIO_h
 #define __itkDCMTKImageIO_h
+#include "ITKIODCMTKExport.h"
 
 
 #include <fstream>
@@ -35,7 +36,7 @@ namespace itk
  *
  * \ingroup ITKIODCMTK
  */
-class DCMTKImageIO:public ImageIOBase
+class ITKIODCMTK_EXPORT DCMTKImageIO:public ImageIOBase
 {
 public:
   /** Standard class typedefs. */
@@ -49,12 +50,27 @@ public:
   /** Run-time type information (and related methods). */
   itkTypeMacro(DCMTKImageIO, ImageIOBase);
 
+  /** enum for DCMTK log level.  These are defined here without
+   *  reference to DCMTK library enumerations, to avoid including
+   * dcmtk headers in this header.
+   */
+  enum LogLevel
+  {
+    TRACE_LOG_LEVEL = 0,
+    DEBUG_LOG_LEVEL,
+    INFO_LOG_LEVEL ,
+    WARN_LOG_LEVEL ,
+    ERROR_LOG_LEVEL,
+    FATAL_LOG_LEVEL,
+    OFF_LOG_LEVEL,
+  };
+
   /** */
   void SetDicomImagePointer( DicomImage* UserProvided)
     {
     m_DImage = UserProvided;
     m_DicomImageSetByUser = true;
-    };
+    }
 
   /*-------- This part of the interfaces deals with reading data. ----- */
 
@@ -81,6 +97,11 @@ public:
    * that the IORegions has been set properly. */
   virtual void Write(const void *buffer);
 
+  /** Set the DCMTK Message Logging Level */
+  void SetLogLevel(LogLevel level);
+  /** Get the DCMTK Message Logging Level */
+  LogLevel GetLogLevel() const;
+
   DCMTKImageIO();
   ~DCMTKImageIO();
   void PrintSelf(std::ostream & os, Indent indent) const;
