@@ -25,20 +25,20 @@
 namespace itk
 {
 
-HDF5ImageIO::HDF5ImageIO() : m_H5File(0),
-                             m_VoxelDataSet(0),
+HDF5ImageIO::HDF5ImageIO() : m_H5File(ITK_NULLPTR),
+                             m_VoxelDataSet(ITK_NULLPTR),
                              m_ImageInformationWritten(false)
 {
 }
 
 HDF5ImageIO::~HDF5ImageIO()
 {
-  if(this->m_VoxelDataSet != 0)
+  if(this->m_VoxelDataSet != ITK_NULLPTR)
     {
     m_VoxelDataSet->close();
     delete m_VoxelDataSet;
     }
-  if(this->m_H5File != 0)
+  if(this->m_H5File != ITK_NULLPTR)
     {
     this->m_H5File->close();
     delete this->m_H5File;
@@ -180,8 +180,6 @@ PredTypeToComponentType(H5::DataType &type)
     }
   itkGenericExceptionMacro(<< "unsupported data type "
                            << type.fromClass());
-  // never reached but silences warning
-  return ImageIOBase::UCHAR;
 }
 
 H5::PredType
@@ -390,7 +388,7 @@ TScalar
 HDF5ImageIO
 ::ReadScalar(const std::string &DataSetName)
 {
-  hsize_t dim;
+  hsize_t dim[1];
   H5::DataSet scalarSet = this->m_H5File->openDataSet(DataSetName);
   H5::DataSpace Space = scalarSet.getSpace();
 
@@ -399,8 +397,8 @@ HDF5ImageIO
     itkExceptionMacro(<< "Wrong # of dims for TransformType "
                       << "in HDF5 File");
     }
-  Space.getSimpleExtentDims(&dim,0);
-  if(dim != 1)
+  Space.getSimpleExtentDims(dim,ITK_NULLPTR);
+  if(dim[0] != 1)
     {
     itkExceptionMacro(<< "Elements > 1 for scalar type "
                       << "in HDF5 File");
@@ -478,7 +476,7 @@ HDF5ImageIO
 ::ReadVector(const std::string &DataSetName)
 {
   std::vector<TScalar> vec;
-  hsize_t dim;
+  hsize_t dim[1];
   H5::DataSet vecSet = this->m_H5File->openDataSet(DataSetName);
   H5::DataSpace Space = vecSet.getSpace();
 
@@ -487,13 +485,13 @@ HDF5ImageIO
     itkExceptionMacro(<< "Wrong # of dims for TransformType "
                       << "in HDF5 File");
     }
-  Space.getSimpleExtentDims(&dim,0);
-  vec.resize(dim);
-  TScalar *buf = new TScalar[dim];
+  Space.getSimpleExtentDims(dim,ITK_NULLPTR);
+  vec.resize(dim[0]);
+  TScalar *buf = new TScalar[dim[0]];
   H5::PredType vecType =
     GetType<TScalar>();
   vecSet.read(buf,vecType);
-  for(unsigned i = 0; i < dim; i++)
+  for(unsigned i = 0; i < dim[0]; i++)
     {
     vec[i] = buf[i];
     }
@@ -543,7 +541,7 @@ HDF5ImageIO
     itkExceptionMacro(<< " Wrong # of dims for Image Directions "
                       << "in HDF5 File");
     }
-  dirSpace.getSimpleExtentDims(dim,0);
+  dirSpace.getSimpleExtentDims(dim,ITK_NULLPTR);
   rval.resize(dim[1]);
   for(unsigned i = 0; i < dim[1]; i++)
     {
@@ -618,10 +616,10 @@ HDF5ImageIO
 {
   const char *extensions[] =
     {
-      ".hdf",".h4",".hdf4",".h5",".hdf5",".he4",".he5",".hd5",0,
+      ".hdf",".h4",".hdf4",".h5",".hdf5",".he4",".he5",".hd5",ITK_NULLPTR,
     };
   std::string ext(itksys::SystemTools::GetFilenameLastExtension(FileNameToWrite));
-  for(unsigned i = 0; extensions[i] != 0; i++)
+  for(unsigned i = 0; extensions[i] != ITK_NULLPTR; i++)
     {
     if(ext == extensions[i])
       {
@@ -787,13 +785,13 @@ HDF5ImageIO
       H5::DataSet metaDataSet = this->m_H5File->openDataSet(localMetaDataName);
       H5::DataType metaDataType = metaDataSet.getDataType();
       H5::DataSpace metaDataSpace = metaDataSet.getSpace();
-      if(metaDataSpace.getSimpleExtentNdims() > 1)
+      if(metaDataSpace.getSimpleExtentNdims() != 1)
         {
         // ignore > 1D metadata
         continue;
         }
-      hsize_t metaDataDims;
-      metaDataSpace.getSimpleExtentDims(&metaDataDims);
+      hsize_t metaDataDims[1];
+      metaDataSpace.getSimpleExtentDims(metaDataDims);
       //
       // work around bool/int confusion on disk.
       if(metaDataType == H5::PredType::NATIVE_INT)
@@ -823,7 +821,7 @@ HDF5ImageIO
           this->StoreMetaData<int>(&metaDict,
                               localMetaDataName,
                               name,
-                              metaDataDims);
+                              metaDataDims[0]);
           }
         }
       else if(metaDataType == H5::PredType::NATIVE_CHAR)
@@ -831,63 +829,63 @@ HDF5ImageIO
         this->StoreMetaData<char>(&metaDict,
                                   localMetaDataName,
                                   name,
-                                  metaDataDims);
+                                  metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_UCHAR)
         {
         this->StoreMetaData<unsigned char>(&metaDict,
                                            localMetaDataName,
                                            name,
-                                           metaDataDims);
+                                           metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_SHORT)
         {
         this->StoreMetaData<short>(&metaDict,
                                    localMetaDataName,
                                    name,
-                                   metaDataDims);
+                                   metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_USHORT)
         {
         this->StoreMetaData<unsigned short>(&metaDict,
                                             localMetaDataName,
                                             name,
-                                            metaDataDims);
+                                            metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_UINT)
         {
         this->StoreMetaData<unsigned int>(&metaDict,
                                           localMetaDataName,
                                           name,
-                                          metaDataDims);
+                                          metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_LONG)
         {
         this->StoreMetaData<long>(&metaDict,
                                   localMetaDataName,
                                   name,
-                                  metaDataDims);
+                                  metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_ULONG)
         {
         this->StoreMetaData<unsigned long>(&metaDict,
                                            localMetaDataName,
                                            name,
-                                           metaDataDims);
+                                           metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_FLOAT)
         {
         this->StoreMetaData<float>(&metaDict,
                                    localMetaDataName,
                                    name,
-                                   metaDataDims);
+                                   metaDataDims[0]);
         }
       else if(metaDataType == H5::PredType::NATIVE_DOUBLE)
         {
         this->StoreMetaData<double>(&metaDict,
                                     localMetaDataName,
                                     name,
-                                    metaDataDims);
+                                    metaDataDims[0]);
         }
       else
         {
@@ -979,7 +977,7 @@ HDF5ImageIO
   std::string VoxelDataName(ImageGroup);
   VoxelDataName += "/0";
   VoxelDataName += VoxelData;
-  if(this->m_VoxelDataSet == 0)
+  if(this->m_VoxelDataSet == ITK_NULLPTR)
     {
     this->m_VoxelDataSet = new H5::DataSet();
     *(this->m_VoxelDataSet) = this->m_H5File->openDataSet(VoxelDataName);
@@ -1000,7 +998,7 @@ HDF5ImageIO
 {
   MetaDataObject<TType> *metaObj =
     dynamic_cast<MetaDataObject<TType> *>(metaObjBase);
-  if(metaObj == 0)
+  if(metaObj == ITK_NULLPTR)
     {
     return false;
     }
@@ -1017,7 +1015,7 @@ HDF5ImageIO
   typedef MetaDataObject< Array<TType> > MetaDataArrayObject;
     MetaDataArrayObject *metaObj =
     dynamic_cast<MetaDataArrayObject  *>(metaObjBase);
-  if(metaObj == 0)
+  if(metaObj == ITK_NULLPTR)
     {
     return false;
     }
@@ -1186,10 +1184,10 @@ HDF5ImageIO
         dynamic_cast<MetaDataObject<char *> *>(metaObj);
       MetaDataObject<const char *> *constCstringObj =
         dynamic_cast<MetaDataObject<const char *> *>(metaObj);
-      if(cstringObj != 0 || constCstringObj != 0)
+      if(cstringObj != ITK_NULLPTR || constCstringObj != ITK_NULLPTR)
         {
         const char *val;
-        if(cstringObj != 0)
+        if(cstringObj != ITK_NULLPTR)
           {
           val = cstringObj->GetMetaDataObjectValue();
           }
@@ -1206,7 +1204,7 @@ HDF5ImageIO
       {
       MetaDataObject<std::string> *stdStringObj =
         dynamic_cast<MetaDataObject<std::string> *>(metaObj);
-      if(stdStringObj != 0)
+      if(stdStringObj != ITK_NULLPTR)
         {
         std::string val = stdStringObj->GetMetaDataObjectValue();
         this->WriteString(objName,val);
@@ -1281,7 +1279,7 @@ HDF5ImageIO
 
     //
     // Create DataSet Once, potentially write to it many times
-    if(this->m_VoxelDataSet == 0)
+    if(this->m_VoxelDataSet == ITK_NULLPTR)
       {
       this->m_VoxelDataSet = new H5::DataSet();
       *(this->m_VoxelDataSet) = this->m_H5File->createDataSet(VoxelDataName,
