@@ -33,7 +33,9 @@
 #include "itkImageRegionSplitterBase.h"
 
 #include "vnl/vnl_vector.h"
+#include "vcl_compiler.h"
 
+#include <fstream>
 #include <string>
 
 namespace itk
@@ -523,7 +525,7 @@ public:
 protected:
   ImageIOBase();
   ~ImageIOBase();
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   virtual const ImageRegionSplitterBase* GetImageRegionSplitter(void) const;
 
@@ -613,6 +615,38 @@ protected:
    * next slice. Returns m_Strides[3]. */
   SizeType GetSliceStride() const;
 
+  /** \brief Opens a file for reading and random access
+   *
+   * \param[out] inputStream is an istream presumed to be opened for reading
+   * \param[in] filename is the name of the file
+   * \param[in] ascii optional (default is false);
+   *                  if true than the file will be opened in ASCII mode,
+   *                  which generally only applies to Windows
+   *
+   * The stream is closed if it's already opened. If an error is
+   * encountered than an exception will be thrown.
+   */
+  virtual void OpenFileForReading(std::ifstream & inputStream, const std::string & filename,
+                                  bool ascii = false);
+
+  /** \brief Opens a file for writing and random access
+   *
+   * \param[out] outputStream is an ostream presumed to be opened for writing
+   * \param[in] filename is the name of the file
+   * \param[in] truncate optional (default is true);
+   *                     if true than the file's existing content is truncated,
+   *                     if false than the file is opened for reading and
+   *                     writing with existing content intact
+   * \param[in] ascii optional (default is false);
+   *                  if true than the file will be opened in ASCII mode,
+   *                  which generally only applies to Windows
+   *
+   * The stream is closed if it's already opened. If an error is
+   * encountered than an exception will be thrown.
+   */
+  virtual void OpenFileForWriting(std::ofstream & outputStream, const std::string & filename,
+                                  bool truncate = true, bool ascii = false);
+
   /** Convenient method to write a buffer as ASCII text. */
   virtual void WriteBufferAsASCII(std::ostream & os, const void *buffer,
                           IOComponentType ctype,
@@ -657,6 +691,10 @@ private:
     static const IOComponentType CType = ctype; \
   }
 
+// the following typemaps are not platform independent
+#if  VCL_CHAR_IS_SIGNED
+IMAGEIOBASE_TYPEMAP(signed char, CHAR);
+#endif // VCL_CHAR_IS_SIGNED
 IMAGEIOBASE_TYPEMAP(char, CHAR);
 IMAGEIOBASE_TYPEMAP(unsigned char, UCHAR);
 IMAGEIOBASE_TYPEMAP(short, SHORT);
