@@ -155,8 +155,13 @@ public:
   itkBooleanMacro(UseStreaming);
 
 protected:
-  ImageSeriesReader():m_ImageIO(0), m_ReverseOrder(false),
-    m_UseStreaming(true), m_MetaDataDictionaryArrayUpdate(true) {}
+  ImageSeriesReader() :
+    m_ImageIO(ITK_NULLPTR),
+    m_ReverseOrder(false),
+    m_NumberOfDimensionsInImage(0),
+    m_UseStreaming(true),
+    m_MetaDataDictionaryArrayUpdate(true)
+      {}
   ~ImageSeriesReader();
   void PrintSelf(std::ostream & os, Indent indent) const;
 
