@@ -96,7 +96,7 @@ public:
 protected:
   NumericSeriesFileNames();
   ~NumericSeriesFileNames() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   NumericSeriesFileNames(const Self &); //purposely not implemented
