@@ -63,18 +63,18 @@ public:
   // see super class for documentation
   //
   // overidden to return true
-  virtual bool CanStreamWrite(void);
+  virtual bool CanStreamWrite(void) ITK_OVERRIDE;
 
   // see super class for documentation
   //
   // overidden to return true
-  virtual bool CanStreamRead(void);
+  virtual bool CanStreamRead(void) ITK_OVERRIDE;
 
   // see super class for documentation
   //
   // If UseStreamedReading is true, then returned region is the
   // requested region parameter.
-  virtual ImageIORegion GenerateStreamableReadRegionFromRequestedRegion(const ImageIORegion & requested) const;
+  virtual ImageIORegion GenerateStreamableReadRegionFromRequestedRegion(const ImageIORegion & requested) const ITK_OVERRIDE;
 
   // see super class for documentation
   //
@@ -82,12 +82,12 @@ public:
   // GetActualNumberOfSplitsForWritingCanStreamWrite
   virtual unsigned int GetActualNumberOfSplitsForWriting(unsigned int numberOfRequestedSplits,
                                                          const ImageIORegion & pasteRegion,
-                                                         const ImageIORegion & largestPossibleRegion);
+                                                         const ImageIORegion & largestPossibleRegion) ITK_OVERRIDE;
 
 protected:
   StreamingImageIOBase();
   // virtual ~StreamingImageIOBase(); not needed
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** \brief Returns true if GetIORegion is not the same size as the
    * largest region give by GetNumberOfDimensions.
@@ -152,24 +152,6 @@ protected:
    */
   virtual SizeType GetDataPosition(void) const { return this->GetHeaderSize(); }
 
-  /** \brief Opens a file for reading and random access
-   *
-   * The stream is closed if it's already opened. If an error is
-   * encountered then an exception will be thrown.
-   */
-  virtual void OpenFileForReading(std::ifstream & os, const char *filename);
-
-  /** \brief Opens a file for writing and random access
-   *
-   * \param os is an ostream presumed to be opened for writing
-   * \param filename is the name of the file
-   * \param truncate if true then the file is truncated
-   *
-   * The stream is closed if it's already opened. If an error is
-   * encountered then an exception will be thrown.
-   */
-  virtual void OpenFileForWriting(std::ofstream & os, const char *filename, bool truncate);
-
 private:
   StreamingImageIOBase(const Self &); //purposely not implemented
   void operator=(const Self &);       //purposely not implemented
