@@ -21,6 +21,8 @@
 #include "itkSimpleFastMutexLock.h"
 #include "itkMutexLockHolder.h"
 
+#include "itksys/SystemTools.hxx"
+
 namespace itk
 {
 ImageIOBase::ImageIOBase():
@@ -78,7 +80,7 @@ void ImageIOBase::Resize(const unsigned int numDimensions,
                          const unsigned int *dimensions)
 {
   m_NumberOfDimensions = numDimensions;
-  if ( dimensions != NULL )
+  if ( dimensions != ITK_NULLPTR )
     {
     for ( unsigned int i = 0; i < m_NumberOfDimensions; i++ )
       {
@@ -162,7 +164,8 @@ void ImageIOBase::SetDirection(unsigned int i, const vnl_vector< double > & dire
   this->Modified();
   std::vector< double > v;
   v.resize( m_Direction.size() );
-  for ( unsigned int j = 0; j < v.size(); j++ )
+  // Note: direction.size() <= v.size().
+  for ( unsigned int j = 0; j < direction.size(); j++ )
     {
     v[j] = direction[j];
     }
@@ -197,7 +200,6 @@ const std::type_info & ImageIOBase::GetComponentTypeInfo() const
     default:
       itkExceptionMacro ("Unknown component type: " << m_ComponentType);
     }
-  return typeid( ImageIOBase::UnknownType );
 }
 
 void ImageIOBase::ComputeStrides()
@@ -331,7 +333,6 @@ unsigned int ImageIOBase::GetPixelSize() const
     {
     itkExceptionMacro ("Unknown pixel or component type: ("
                        << m_PixelType << ", " << m_ComponentType << ")");
-    return 0;
     }
 
   return this->GetComponentSize() * this->GetNumberOfComponents();
@@ -365,8 +366,6 @@ unsigned int ImageIOBase::GetComponentSize() const
     default:
       itkExceptionMacro ("Unknown component type: " << m_ComponentType);
     }
-
-  return 0;
 }
 
 std::string ImageIOBase::GetFileTypeAsString(FileType t) const
@@ -556,6 +555,94 @@ ImageIOBase::IOPixelType ImageIOBase::GetPixelTypeFromString(const std::string &
     }
 }
 
+void ImageIOBase::OpenFileForReading(std::ifstream & inputStream, const std::string & filename,
+                                     bool ascii)
+{
+  // Make sure that we have a file to
+  if ( filename.empty() )
+    {
+    itkExceptionMacro( << "A FileName must be specified." );
+    }
+
+  // Close file from any previous image
+  if ( inputStream.is_open() )
+    {
+    inputStream.close();
+    }
+
+  // Open the new file for reading
+  itkDebugMacro( << "Opening file for reading: " << filename );
+
+  std::ios::openmode mode = std::ios::in;
+  if ( !ascii )
+    {
+    mode |= std::ios::binary;
+    }
+
+  inputStream.open( filename.c_str(), mode );
+
+  if ( !inputStream.is_open() || inputStream.fail() )
+    {
+    itkExceptionMacro( << "Could not open file: "
+                       << filename << " for reading."
+                       << std::endl
+                       << "Reason: "
+                       << itksys::SystemTools::GetLastSystemError() );
+    }
+}
+
+void ImageIOBase::OpenFileForWriting(std::ofstream & outputStream, const std::string & filename,
+                                     bool truncate, bool ascii)
+{
+  // Make sure that we have a file to
+  if ( filename.empty() )
+    {
+    itkExceptionMacro( << "A FileName must be specified." );
+    }
+
+  // Close file from any previous image
+  if ( outputStream.is_open() )
+    {
+    outputStream.close();
+    }
+
+  // Open the new file for writing
+  itkDebugMacro( << "Opening file for writing: " << filename );
+
+  std::ios::openmode mode = std::ios::out;
+  if ( truncate )
+    {
+    // typically, ios::out also implies ios::trunc, but being explicit is safer
+    mode |= std::ios::trunc;
+    }
+  else
+    {
+    mode |= std::ios::in;
+    // opening a nonexistent file for reading + writing is not allowed on some platforms
+    if ( !itksys::SystemTools::FileExists( filename.c_str() ) )
+      {
+      itksys::SystemTools::Touch( filename.c_str(), true );
+      // don't worry about failure here, errors should be detected later when the file
+      // is "actually" opened, unless there is a race condition
+      }
+    }
+  if ( !ascii )
+    {
+    mode |= std::ios::binary;
+    }
+
+  outputStream.open( filename.c_str(), mode );
+
+  if ( !outputStream.is_open() || outputStream.fail() )
+    {
+    itkExceptionMacro( << "Could not open file: "
+                       << filename << " for writing."
+                       << std::endl
+                       << "Reason: "
+                       << itksys::SystemTools::GetLastSystemError() );
+    }
+}
+
 namespace
 {
 template< typename TComponent >
