@@ -515,7 +515,7 @@ protected:
   MeshIOBase();
   virtual ~MeshIOBase(){}
 
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Insert an extension to the list of supported extensions for reading. */
   void AddSupportedReadExtension(const char *extension);
