@@ -23,11 +23,12 @@
 namespace itk
 {
 FreeSurferBinaryMeshIO
-::FreeSurferBinaryMeshIO()
+::FreeSurferBinaryMeshIO() :
+  m_FilePosition(0),
+  m_FileTypeIdentifier(0)
 {
   this->AddSupportedWriteExtension(".fsb");
   this->AddSupportedWriteExtension(".fcv");
-  m_FilePosition = 0;
 }
 
 bool
@@ -282,7 +283,6 @@ FreeSurferBinaryMeshIO
   if ( this->m_FileName == "" )
     {
     itkExceptionMacro("No Input FileName");
-    return;
     }
 
   // Write to output file
@@ -293,7 +293,6 @@ FreeSurferBinaryMeshIO
     {
     itkExceptionMacro("Unable to open file\n"
                       "outputFilename= " << this->m_FileName);
-    return;
     }
 
   if ( this->m_UpdatePoints && this->m_UpdateCells )
@@ -339,7 +338,6 @@ FreeSurferBinaryMeshIO
   if ( this->m_FileName == "" )
     {
     itkExceptionMacro("No Input FileName");
-    return;
     }
 
   // Write to output file
@@ -349,7 +347,6 @@ FreeSurferBinaryMeshIO
     {
     itkExceptionMacro("Unable to open file\n"
                       "outputFilename= " << this->m_FileName);
-    return;
     }
 
   // Write points
@@ -449,7 +446,6 @@ FreeSurferBinaryMeshIO
   if ( this->m_FileName == "" )
     {
     itkExceptionMacro("No Input FileName");
-    return;
     }
 
   // Write to output file
@@ -459,7 +455,6 @@ FreeSurferBinaryMeshIO
     {
     itkExceptionMacro("Unable to open file\n"
                       "outputFilename= " << this->m_FileName);
-    return;
     }
 
   // Write triangles
@@ -547,7 +542,6 @@ FreeSurferBinaryMeshIO
   if ( this->m_FileName == "" )
     {
     itkExceptionMacro("No Input FileName");
-    return;
     }
 
   // Write to output file
@@ -557,7 +551,6 @@ FreeSurferBinaryMeshIO
     {
     itkExceptionMacro("Unable to open file\n"
                       "outputFilename= " << this->m_FileName);
-    return;
     }
 
   // Write point data
