@@ -18,9 +18,9 @@
 
 #include <iostream>
 #include <cstdlib>
+#include <cmath>
 #include <metaMesh.h>
 #include <metaScene.h>
-#include "vcl_cmath.h"
 #include "itksys/SystemTools.hxx"
 
 
@@ -147,7 +147,7 @@ bool TestingMetaMesh(MetaMesh* _mesh)
   float f = (float)(0.1);
   for(j=0;j< static_cast<int>(_mesh->GetCellData().size());j++)
     {
-    if(((*it_cd)->m_Id != j) || (vcl_fabs((float)(static_cast<MeshData<float>*>(*it_cd)->m_Data)-f)>0.001))
+    if(((*it_cd)->m_Id != j) || (std::fabs((float)(static_cast<MeshData<float>*>(*it_cd)->m_Data)-f)>0.001))
       {
       std::cout << "CellData ID = " << (*it_cd)->m_Id << " : " << (float)(static_cast<MeshData<float>*>(*it_cd)->m_Data) << " : " << f << std::endl;
       std::cout << "[FAILED]" << std::endl;
