@@ -125,9 +125,9 @@ static char * str_intent(unsigned int intent)
     }
 }
 
-/*----------------------------------------------------------------------*/
-/*! display the contents of the nifti_1_header (send to stdout)
- *--------------------------------------------------------------------*/
+//--------------------------------------------------------------------
+// display the contents of the nifti_1_header (send to stdout)
+//--------------------------------------------------------------------
 static int DumpNiftiHeader(const std::string & fname)
 {
   int             c;
@@ -173,7 +173,7 @@ static int DumpNiftiHeader(const std::string & fname)
           hp->intent_p1, hp->intent_p2, hp->intent_p3,
           str_intent(hp->intent_code),
           hp->datatype, hp->bitpix, hp->slice_start);
-  /* break pixdim over 2 lines */
+  // break pixdim over 2 lines
   for ( c = 0; c < 4; c++ )
     {
     fprintf(stderr, " %f", hp->pixdim[c]);
@@ -348,7 +348,7 @@ NiftiImageIO
 }
 
 NiftiImageIO::NiftiImageIO():
-  m_NiftiImage(0),
+  m_NiftiImage(ITK_NULLPTR),
   m_RescaleSlope(1.0),
   m_RescaleIntercept(0.0),
   m_OnDiskComponentType(UNKNOWNCOMPONENTTYPE),
@@ -397,9 +397,9 @@ NiftiImageIO
 bool
 NiftiImageIO::MustRescale()
 {
-  return vcl_abs(this->m_RescaleSlope) > vcl_numeric_limits< double >::epsilon()
-         && ( vcl_abs(this->m_RescaleSlope - 1.0) > vcl_numeric_limits< double >::epsilon()
-              || vcl_abs(this->m_RescaleIntercept) > vcl_numeric_limits< double >::epsilon() );
+  return std::abs(this->m_RescaleSlope) > std::numeric_limits< double >::epsilon()
+         && ( std::abs(this->m_RescaleSlope - 1.0) > std::numeric_limits< double >::epsilon()
+              || std::abs(this->m_RescaleIntercept) > std::numeric_limits< double >::epsilon() );
 }
 
 // Internal function to rescale pixel according to Rescale Slope/Intercept
@@ -431,7 +431,7 @@ CastCopy(float *to, void *from, size_t pixelcount)
 
 void NiftiImageIO::Read(void *buffer)
 {
-  void *data = 0;
+  void *data = ITK_NULLPTR;
 
   ImageIORegion            regionToRead = this->GetIORegion();
   ImageIORegion::SizeType  size = regionToRead.GetSize();
@@ -467,14 +467,14 @@ void NiftiImageIO::Read(void *buffer)
     _size[4] = numComponents;
     }
   // Free memory if any was occupied already (incase of re-using the IO filter).
-  if ( this->m_NiftiImage != NULL )
+  if ( this->m_NiftiImage != ITK_NULLPTR )
     {
     nifti_image_free(this->m_NiftiImage);
     }
   //
   // allocate nifti image...
   this->m_NiftiImage = nifti_image_read(this->GetFileName(), false);
-  if ( this->m_NiftiImage == NULL )
+  if ( this->m_NiftiImage == ITK_NULLPTR )
     {
     itkExceptionMacro( << "nifti_image_read (just header) failed for file: "
                        << this->GetFileName() );
@@ -507,7 +507,7 @@ void NiftiImageIO::Read(void *buffer)
     if ( nifti_read_subregion_image(this->m_NiftiImage,
                                     _origin,
                                     _size,
-                                    &data) == -1 || this->m_NiftiImage == NULL )
+                                    &data) == -1 )
       {
       itkExceptionMacro( << "nifti_read_subregion_image failed for file: "
                          << this->GetFileName() );
@@ -752,7 +752,7 @@ NiftiImageIO
     {
     return true;
     }
-  /* image_FTYPE < 0 */
+  // image_FTYPE < 0
   return false;
 }
 
@@ -932,7 +932,7 @@ NiftiImageIO
 #endif
     prev = this->GetFileName();
     }
-  if ( this->m_NiftiImage == 0 )
+  if ( this->m_NiftiImage == ITK_NULLPTR )
     {
     itkExceptionMacro(<< this->GetFileName() << " is not recognized as a NIFTI file");
     }
@@ -1259,7 +1259,7 @@ NiftiImageIO
 
   // We don't need the image anymore
   nifti_image_free(this->m_NiftiImage);
-  this->m_NiftiImage = 0;
+  this->m_NiftiImage = ITK_NULLPTR;
 }
 
 namespace
@@ -1278,10 +1278,6 @@ inline mat44 mat44_transpose(mat44 in)
   return out;
 }
 }
-/**
- * For Nifti this does not write a file, it only fills in the
- * appropriate header information.
- */
 void
 NiftiImageIO
 ::WriteImageInformation(void)
@@ -1303,7 +1299,7 @@ NiftiImageIO
     }
 
   // fill out the image header.
-  if ( this->m_NiftiImage == 0 )
+  if ( this->m_NiftiImage == ITK_NULLPTR )
     {
     this->m_NiftiImage = nifti_simple_init_nim();
     }
@@ -1313,7 +1309,7 @@ NiftiImageIO
   //
   // set the file type
   const char *tempextension = nifti_find_file_extension( FName.c_str() );
-  if ( tempextension == NULL )
+  if ( tempextension == ITK_NULLPTR )
     {
     itkExceptionMacro(
       << "Bad Nifti file name. No extension found for file: " << FName);
@@ -1591,19 +1587,8 @@ NiftiImageIO
   //     -----------------------------------------------------
   this->m_NiftiImage->scl_slope = 1.0f;
   this->m_NiftiImage->scl_inter = 0.0f;
-  this->SetNIfTIOrientationFromImageIO( this->GetNumberOfDimensions(), this->GetNumberOfDimensions() ); //TODO:
-                                                                                                        // Note
-                                                                                                        // both
-                                                                                                        // arguments
-                                                                                                        // are
-                                                                                                        // the
-                                                                                                        // same,
-                                                                                                        // no
-                                                                                                        // need
-                                                                                                        // to
-                                                                                                        // distinguish
-                                                                                                        // between
-                                                                                                        // them.
+  //TODO: Note both arguments are the same, no need to distinguish between them.
+  this->SetNIfTIOrientationFromImageIO( this->GetNumberOfDimensions(), this->GetNumberOfDimensions() );
 }
 
 namespace
@@ -1620,7 +1605,7 @@ void Normalize(std::vector< double > & x)
     {
     return;
     }
-  sum = vcl_sqrt(sum);
+  sum = std::sqrt(sum);
   for ( unsigned int i = 0; i < x.size(); i++ )
     {
     x[i] = x[i] / sum;
@@ -1823,9 +1808,9 @@ NiftiImageIO::SetNIfTIOrientationFromImageIO(unsigned short int origdims, unsign
                           &( this->m_NiftiImage->qoffset_x ),
                           &( this->m_NiftiImage->qoffset_y ),
                           &( this->m_NiftiImage->qoffset_z ),
-                          0,
-                          0,
-                          0,
+                          ITK_NULLPTR,
+                          ITK_NULLPTR,
+                          ITK_NULLPTR,
                           &( this->m_NiftiImage->qfac ) );
   // copy q matrix to s matrix
   this->m_NiftiImage->qto_xyz =  matrix;
@@ -1851,13 +1836,11 @@ NiftiImageIO::SetNIfTIOrientationFromImageIO(unsigned short int origdims, unsign
   //  this->m_NiftiImage->sform_code = 0;
 }
 
-/**
- * Write the image Information before writing data
- */
 void
 NiftiImageIO
 ::Write(const void *buffer)
 {
+  // Write the image Information before writing data
   this->WriteImageInformation();
   unsigned int numComponents = this->GetNumberOfComponents();
   if ( numComponents == 1
@@ -1869,7 +1852,7 @@ NiftiImageIO
     // for writing.
     this->m_NiftiImage->data = const_cast< void * >( buffer );
     nifti_image_write(this->m_NiftiImage);
-    this->m_NiftiImage->data = 0; // if left pointing to data buffer
+    this->m_NiftiImage->data = ITK_NULLPTR; // if left pointing to data buffer
     // nifti_image_free will try and free this memory
     }
   else  ///Image intent is vector image
@@ -1955,7 +1938,7 @@ NiftiImageIO
     //writing.
     this->m_NiftiImage->data = (void *)nifti_buf;
     nifti_image_write(this->m_NiftiImage);
-    this->m_NiftiImage->data = 0; // if left pointing to data buffer
+    this->m_NiftiImage->data = ITK_NULLPTR; // if left pointing to data buffer
     delete[] nifti_buf;
     }
 }
