@@ -163,12 +163,6 @@ bool NrrdImageIO::CanReadFile(const char *filename)
   // recognized.
   std::string fname = filename;
 
-  if (  fname == "" )
-    {
-    itkDebugMacro(<< "No filename specified.");
-    return false;
-    }
-
   bool                   extensionFound = false;
   std::string::size_type nrrdPos = fname.rfind(".nrrd");
   if ( ( nrrdPos != std::string::npos )
@@ -193,10 +187,11 @@ bool NrrdImageIO::CanReadFile(const char *filename)
   // We have the correct extension, so now check for the Nrrd magic "NRRD",
   // while ignoring the format version (the next four characters)
   std::ifstream inputStream;
-
-  inputStream.open(filename, std::ios::in | std::ios::binary);
-
-  if ( inputStream.fail() )
+  try
+    {
+    this->OpenFileForReading( inputStream, fname );
+    }
+  catch( ExceptionObject & )
     {
     return false;
     }
@@ -549,8 +544,8 @@ void NrrdImageIO::ReadImageInformation()
     // Store key/value pairs in MetaDataDictionary
     char                 key[AIR_STRLEN_SMALL];
     const char *         val;
-    char *               keyPtr = NULL;
-    char *               valPtr = NULL;
+    char *               keyPtr = ITK_NULLPTR;
+    char *               valPtr = ITK_NULLPTR;
     MetaDataDictionary & thisDic = this->GetMetaDataDictionary();
     // Necessary to clear dict if ImageIO object is re-used
     thisDic.Clear();
@@ -747,7 +742,7 @@ void NrrdImageIO::Read(void *buffer)
 
   // Read in the nrrd.  Yes, this means that the header is being read
   // twice: once by NrrdImageIO::ReadImageInformation, and once here
-  if ( nrrdLoad(nrrd, this->GetFileName(), NULL) != 0 )
+  if ( nrrdLoad(nrrd, this->GetFileName(), ITK_NULLPTR) != 0 )
     {
     char *err =  biffGetDone(NRRD); // would be nice to free(err)
     itkExceptionMacro("Read: Error reading "
@@ -1124,8 +1119,8 @@ void NrrdImageIO::Write(const void *buffer)
     }
 
   // Free the nrrd struct but don't touch nrrd->data
-  nrrd = nrrdNix(nrrd);
-  nio = nrrdIoStateNix(nio);
+  nrrdNix(nrrd);
+  nrrdIoStateNix(nio);
 }
 
 } // end namespace itk
