@@ -58,7 +58,7 @@ bool wrapSetjmp( png_structp & png_ptr )
 class PNGFileWrapper
 {
 public:
-  PNGFileWrapper(const char *const fname, const char *const openMode):m_FilePointer(NULL)
+  PNGFileWrapper(const char *const fname, const char *const openMode):m_FilePointer(ITK_NULLPTR)
   {
     m_FilePointer = fopen(fname, openMode);
   }
@@ -93,7 +93,7 @@ bool PNGImageIO::CanReadFile(const char *file)
 
   // Now check the file header
   PNGFileWrapper pngfp(file, "rb");
-  if ( pngfp.m_FilePointer == NULL )
+  if ( pngfp.m_FilePointer == ITK_NULLPTR )
     {
     return false;
     }
@@ -112,8 +112,8 @@ bool PNGImageIO::CanReadFile(const char *file)
     return false;
     }
   png_structp png_ptr = png_create_read_struct
-                          (PNG_LIBPNG_VER_STRING, (png_voidp)NULL,
-                          NULL, NULL);
+                          (PNG_LIBPNG_VER_STRING, (png_voidp)ITK_NULLPTR,
+                          ITK_NULLPTR, ITK_NULLPTR);
   if ( !png_ptr )
     {
     return false;
@@ -123,7 +123,7 @@ bool PNGImageIO::CanReadFile(const char *file)
   if ( !info_ptr )
     {
     png_destroy_read_struct(&png_ptr,
-                            (png_infopp)NULL, (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR, (png_infopp)ITK_NULLPTR);
     return false;
     }
 
@@ -131,7 +131,7 @@ bool PNGImageIO::CanReadFile(const char *file)
   if ( !end_info )
     {
     png_destroy_read_struct(&png_ptr, &info_ptr,
-                            (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR);
     return false;
     }
   png_destroy_read_struct(&png_ptr, &info_ptr,
@@ -156,7 +156,6 @@ void PNGImageIO::Read(void *buffer)
                        << std::endl
                        << "Reason: "
                        << itksys::SystemTools::GetLastSystemError() );
-    return;
     }
   unsigned char header[8];
   size_t temp = fread(header, 1, 8, fp);
@@ -172,33 +171,29 @@ void PNGImageIO::Read(void *buffer)
   if ( !is_png )
     {
     itkExceptionMacro( "File is not png type: " << this->GetFileName() );
-    return;
     }
   png_structp png_ptr = png_create_read_struct
-                          (PNG_LIBPNG_VER_STRING, (png_voidp)NULL,
-                          NULL, NULL);
+                          (PNG_LIBPNG_VER_STRING, (png_voidp)ITK_NULLPTR,
+                          ITK_NULLPTR, ITK_NULLPTR);
   if ( !png_ptr )
     {
     itkExceptionMacro( "File is not png type" << this->GetFileName() );
-    return;
     }
 
   png_infop info_ptr = png_create_info_struct(png_ptr);
   if ( !info_ptr )
     {
     png_destroy_read_struct(&png_ptr,
-                            (png_infopp)NULL, (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR, (png_infopp)ITK_NULLPTR);
     itkExceptionMacro( "File is not png type " << this->GetFileName() );
-    return;
     }
 
   png_infop end_info = png_create_info_struct(png_ptr);
   if ( !end_info )
     {
     png_destroy_read_struct(&png_ptr, &info_ptr,
-                            (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR);
     itkExceptionMacro( "File is not png type " << this->GetFileName() );
-    return;
     }
 
   //  VS 7.1 has problems with setjmp/longjmp in C++ code
@@ -207,7 +202,6 @@ void PNGImageIO::Read(void *buffer)
     {
     png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
     itkExceptionMacro( "File is not png type " << this->GetFileName() );
-    return;
     }
 #endif
 
@@ -281,7 +275,7 @@ void PNGImageIO::Read(void *buffer)
   png_read_image(png_ptr, row_pointers);
   delete[] row_pointers;
   // close the file
-  png_read_end(png_ptr, NULL);
+  png_read_end(png_ptr, ITK_NULLPTR);
   png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
 }
 
@@ -340,8 +334,8 @@ void PNGImageIO::ReadImageInformation()
     return;
     }
   png_structp png_ptr = png_create_read_struct
-                          (PNG_LIBPNG_VER_STRING, (png_voidp)NULL,
-                          NULL, NULL);
+                          (PNG_LIBPNG_VER_STRING, (png_voidp)ITK_NULLPTR,
+                          ITK_NULLPTR, ITK_NULLPTR);
   if ( !png_ptr )
     {
     return;
@@ -351,7 +345,7 @@ void PNGImageIO::ReadImageInformation()
   if ( !info_ptr )
     {
     png_destroy_read_struct(&png_ptr,
-                            (png_infopp)NULL, (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR, (png_infopp)ITK_NULLPTR);
     return;
     }
 
@@ -359,7 +353,7 @@ void PNGImageIO::ReadImageInformation()
   if ( !end_info )
     {
     png_destroy_read_struct(&png_ptr, &info_ptr,
-                            (png_infopp)NULL);
+                            (png_infopp)ITK_NULLPTR);
     return;
     }
 
@@ -517,7 +511,7 @@ void PNGImageIO::WriteSlice(const std::string & fileName, const void *buffer)
     }
 
   png_structp png_ptr = png_create_write_struct
-                          (PNG_LIBPNG_VER_STRING, (png_voidp)NULL, NULL, NULL);
+                          (PNG_LIBPNG_VER_STRING, (png_voidp)ITK_NULLPTR, ITK_NULLPTR, ITK_NULLPTR);
   if ( !png_ptr )
     {
     itkExceptionMacro(<< "Unable to write PNG file! png_create_write_struct failed.");
@@ -527,7 +521,7 @@ void PNGImageIO::WriteSlice(const std::string & fileName, const void *buffer)
   if ( !info_ptr )
     {
     png_destroy_write_struct(&png_ptr,
-                             (png_infopp)NULL);
+                             (png_infopp)ITK_NULLPTR);
     itkExceptionMacro(<< "Unable to write PNG file!. png_create_info_struct failed.");
     }
 
@@ -545,7 +539,6 @@ void PNGImageIO::WriteSlice(const std::string & fileName, const void *buffer)
                        << std::endl
                        << "Reason: "
                        << itksys::SystemTools::GetLastSystemError() );
-    return;
     }
 #endif
 
