@@ -54,17 +54,17 @@ public:
 
 public:
   /** Determine if a file can be read */
-  virtual int CanReadFile(const char *name);
+  virtual int CanReadFile(const char *name) ITK_OVERRIDE;
 
 protected:
   PolygonGroupSpatialObjectXMLFileReader() {}
   virtual ~PolygonGroupSpatialObjectXMLFileReader() {}
 
-  virtual void StartElement(const char *name, const char **atts);
+  virtual void StartElement(const char *name, const char **atts) ITK_OVERRIDE;
 
-  virtual void EndElement(const char *name);
+  virtual void EndElement(const char *name) ITK_OVERRIDE;
 
-  virtual void CharacterDataHandler(const char *inData, int inLength);
+  virtual void CharacterDataHandler(const char *inData, int inLength) ITK_OVERRIDE;
 
 private:
   PolygonGroupSpatialObjectXMLFileReader(const Self &); //purposely not
@@ -102,10 +102,10 @@ public:
   typedef PGroupSpatialObjectType   PolygonGroupType;
   typedef PolygonSpatialObject< 3 > PolygonSpatialObjectType;
   /** Test whether a file is writable. */
-  virtual int CanWriteFile(const char *name);
+  virtual int CanWriteFile(const char *name) ITK_OVERRIDE;
 
   /** Actually write out the file in question */
-  virtual int WriteFile();
+  virtual int WriteFile() ITK_OVERRIDE;
 
 protected:
   PolygonGroupSpatialObjectXMLFileWriter() {}
