@@ -70,7 +70,16 @@ int TIFFReaderInternal::Open(const char *filename)
   struct stat fs;
   if ( stat(filename, &fs) )
     {
+#if defined(_WIN32)
+    struct _stat64 fs64;
+    if ( _stat64(filename, &fs64) )
+      {
+      // Both stat() and _stat64() return != 0
+      return 0;
+      }
+#else
     return 0;
+#endif
     }
 
   this->m_Image = TIFFOpen(filename, "r");
@@ -95,7 +104,7 @@ void TIFFReaderInternal::Clean()
     {
     TIFFClose(this->m_Image);
     }
-  this->m_Image = NULL;
+  this->m_Image = ITK_NULLPTR;
   this->m_Width = 0;
   this->m_Height = 0;
   this->m_SamplesPerPixel = 0;
@@ -124,7 +133,7 @@ void TIFFReaderInternal::Clean()
 
 TIFFReaderInternal::TIFFReaderInternal()
 {
-  this->m_Image           = NULL;
+  this->m_Image           = ITK_NULLPTR;
   this->Clean();
 }
 
@@ -258,6 +267,7 @@ int TIFFReaderInternal::CanRead()
            && ( this->m_Compression == COMPRESSION_NONE
                 || this->m_Compression == COMPRESSION_PACKBITS
                 || this->m_Compression == COMPRESSION_LZW
+                || this->m_Compression == COMPRESSION_DEFLATE
                 )
            && ( this->m_HasValidPhotometricInterpretation )
            && ( this->m_Photometrics == PHOTOMETRIC_RGB
@@ -281,7 +291,7 @@ bool TIFFImageIO::CanReadFile(const char *file)
     }
 
   // Now check if this is a valid TIFF image
-  TIFFErrorHandler save = TIFFSetErrorHandler(0);
+  TIFFErrorHandler save = TIFFSetErrorHandler(ITK_NULLPTR);
   int              res = m_InternalImage->Open(file);
   if ( res )
     {
@@ -1462,6 +1472,7 @@ TIFFImageIO::TIFFImageIO()
   m_Origin[1] = 0.0;
 
   m_Compression = TIFFImageIO::PackBits;
+  m_JPEGQuality = 75;
 
   this->AddSupportedWriteExtension(".tif");
   this->AddSupportedWriteExtension(".TIF");
@@ -1484,13 +1495,14 @@ void TIFFImageIO::PrintSelf(std::ostream & os, Indent indent) const
 {
   Superclass::PrintSelf(os, indent);
   os << indent << "Compression: " << m_Compression << "\n";
+  os << indent << "JPEGQuality: " << m_JPEGQuality << "\n";
 }
 
 void TIFFImageIO::InitializeColors()
 {
-  m_ColorRed    = 0;
-  m_ColorGreen  = 0;
-  m_ColorBlue   = 0;
+  m_ColorRed    = ITK_NULLPTR;
+  m_ColorGreen  = ITK_NULLPTR;
+  m_ColorBlue   = ITK_NULLPTR;
   m_TotalColors = -1;
   m_ImageFormat = TIFFImageIO::NOFORMAT;
 }
@@ -1688,7 +1700,7 @@ void TIFFImageIO::Write(const void *buffer)
 
 void TIFFImageIO::InternalWrite(const void *buffer)
 {
-  char *outPtr = (char *)buffer;
+  const char *outPtr = (const char *)buffer;
 
   unsigned int page, pages = 1;
 
@@ -1819,14 +1831,14 @@ void TIFFImageIO::InternalWrite(const void *buffer)
       {
       switch ( m_Compression )
         {
+        case TIFFImageIO::LZW:
+          itkWarningMacro(<< "LZW compression is patented outside US so it is disabled. packbits compression will be used instead");
         case TIFFImageIO::PackBits:
           compression = COMPRESSION_PACKBITS; break;
         case TIFFImageIO::JPEG:
           compression = COMPRESSION_JPEG; break;
         case TIFFImageIO::Deflate:
           compression = COMPRESSION_DEFLATE; break;
-        case TIFFImageIO::LZW:
-          compression = COMPRESSION_LZW; break;
         default:
           compression = COMPRESSION_NONE;
         }
@@ -1842,15 +1854,8 @@ void TIFFImageIO::InternalWrite(const void *buffer)
 
     if ( compression == COMPRESSION_JPEG )
       {
-      TIFFSetField(tif, TIFFTAG_JPEGQUALITY, 75); // Parameter
+      TIFFSetField(tif, TIFFTAG_JPEGQUALITY, m_JPEGQuality);
       TIFFSetField(tif, TIFFTAG_JPEGCOLORMODE, JPEGCOLORMODE_RGB);
-      photometric = PHOTOMETRIC_YCBCR;
-      }
-    else if ( compression == COMPRESSION_LZW )
-      {
-      predictor = 2;
-      TIFFSetField(tif, TIFFTAG_PREDICTOR, predictor);
-      itkDebugMacro(<< "LZW compression is patented outside US so it is disabled");
       }
     else if ( compression == COMPRESSION_DEFLATE )
       {
@@ -1959,12 +1964,37 @@ void TIFFImageIO::InternalWrite(const void *buffer)
 // With the TIFF 4.0 (aka bigtiff ) interface the tiff field structure
 // was renamed and became an opaque type requiring function to
 // access. The follow are some macros for portable access.
-#ifdef TIFF_INT64_T // detect if libtiff4
+#ifdef ITK_TIFF_HAS_TIFFFieldReadCount
 #define itkTIFFFieldReadCount( TIFFField ) TIFFFieldReadCount( TIFFField )
 #define itkTIFFFieldPassCount( TIFFField ) TIFFFieldPassCount( TIFFField )
 #define itkTIFFFieldDataType( TIFFField )  TIFFFieldDataType( TIFFField )
 #define itkTIFFField TIFFField
-#else
+#elif defined(ITK_TIFF_HAS_TIFFField)
+} // end namespace itk
+/// Tiff 4.0.0-4.0.2 had _TIFFField as a private structure, but missing the
+/// required access mehods added in 4.0.3, This is a copy of the
+/// structure from tiff_dir.h.
+typedef enum {ITK_TIFF_MOC_1 = 0,ITK_TIFF_MOC_2=51 } ITK_TIFF_MOC_TIFFSetGetFieldType;
+struct _TIFFField {
+  uint32 field_tag;                       /* field's tag */
+  short field_readcount;                  /* read count/TIFF_VARIABLE/TIFF_SPP */
+  short field_writecount;                 /* write count/TIFF_VARIABLE */
+  TIFFDataType field_type;                /* type of associated data */
+  uint32 reserved;                        /* reserved for future extension */
+  ITK_TIFF_MOC_TIFFSetGetFieldType set_field_type;     /* type to be passed to TIFFSetField */
+  ITK_TIFF_MOC_TIFFSetGetFieldType get_field_type;     /* type to be passed to TIFFGetField */
+  unsigned short field_bit;               /* bit in fieldsset bit vector */
+  unsigned char field_oktochange;         /* if true, can change while writing */
+  unsigned char field_passcount;          /* if true, pass dir count on set */
+  char* field_name;                       /* ASCII name */
+  TIFFFieldArray* field_subfields;        /* if field points to child ifds, child ifd field definition array */
+};
+namespace itk {
+#define itkTIFFFieldReadCount( TIFFField ) ((TIFFField)->field_readcount)
+#define itkTIFFFieldPassCount( TIFFField ) ((TIFFField)->field_passcount)
+#define itkTIFFFieldDataType( TIFFField ) ((TIFFField)->field_type)
+#define itkTIFFField TIFFField
+#else // libtiff version 3
 #define itkTIFFFieldReadCount( TIFFFieldInfo ) ((TIFFFieldInfo)->field_readcount)
 #define itkTIFFFieldPassCount( TIFFFieldInfo ) ((TIFFFieldInfo)->field_passcount)
 #define itkTIFFFieldDataType( TIFFFieldInfo ) ((TIFFFieldInfo)->field_type)
@@ -1984,7 +2014,7 @@ bool TIFFImageIO::CanFindTIFFTag(unsigned int t)
 
   const itkTIFFField *fld = TIFFFieldWithTag(m_InternalImage->m_Image, tag);
 
-  if ( fld == NULL )
+  if ( fld == ITK_NULLPTR )
     {
     return false;
     }
@@ -1999,18 +2029,18 @@ void * TIFFImageIO::ReadRawByteFromTag(unsigned int t, unsigned int & value_coun
     itkExceptionMacro(<< "Need to call CanReadFile before");
     }
   ttag_t           tag = t;
-  void *           raw_data = NULL;
+  void *           raw_data = ITK_NULLPTR;
 
   const itkTIFFField *fld = TIFFFieldWithTag(m_InternalImage->m_Image, tag);
 
-  if ( fld == NULL )
+  if ( fld == ITK_NULLPTR )
     {
     itkExceptionMacro(<< "fld is NULL");
     }
 
   if ( !itkTIFFFieldPassCount( fld ) )
     {
-    return NULL;
+    return ITK_NULLPTR;
     }
 
   int ret = 0;
