@@ -18,7 +18,6 @@
 #ifndef __itkXMLFile_h
 #define __itkXMLFile_h
 #include "itkLightProcessObject.h"
-#include "expat.h"
 #include <fstream>
 
 namespace itk
@@ -66,7 +65,7 @@ public:
 protected:
   XMLReaderBase() {}
   virtual ~XMLReaderBase() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Instantiates and invokes the XML parser for the file named by
    * m_Filename.  The parser will throw an exception in the case of XML
@@ -104,7 +103,10 @@ public:
   T * GetOutputObject(void) { return m_OutputObject; }
 
 protected:
-  XMLReader() {}
+  XMLReader() :
+    m_OutputObject(ITK_NULLPTR)
+  {}
+
   virtual ~XMLReader() {}
 
   T *m_OutputObject;
@@ -134,7 +136,7 @@ public:
    */
   XMLWriterBase()
   {
-    m_InputObject = 0;
+    m_InputObject = ITK_NULLPTR;
   }
 
   /** Set the filename to write */
