@@ -21,6 +21,7 @@
 #include "itkXMLFile.h"
 #include "itksys/SystemTools.hxx"
 #include <fstream>
+#include "expat.h"
 
 namespace itk
 {
@@ -62,7 +63,7 @@ static void itkXMLParserCharacterDataHandler(void *parser, const char *data,
 void
 XMLReaderBase::parse(void)
 {
-  XML_Parser Parser = XML_ParserCreate(0);
+  XML_Parser Parser = XML_ParserCreate(ITK_NULLPTR);
 
   XML_SetElementHandler(Parser,
                         &itkXMLParserStartElement,
