@@ -59,8 +59,8 @@ namespace itk
  * \ingroup ITKReview
  */
 
-template< class TInputImage, class TOutputImage, class TAttribute, class TFunction >
-class ITK_EXPORT AttributeMorphologyBaseImageFilter:
+template< typename TInputImage, typename TOutputImage, typename TAttribute, typename TFunction >
+class AttributeMorphologyBaseImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
