@@ -28,7 +28,6 @@
 #include "vnl/algo/vnl_symmetric_eigensystem.h"
 #include "vnl/vnl_det.h"
 #include "vnl/vnl_math.h"
-#include "vcl_cmath.h"
 
 namespace itk
 {
@@ -129,7 +128,7 @@ public:
                            itkGetStaticConstMacro(ImageDimension) *2 > BoundingBoxFloatType;
 
   //typedef itk::FixedArray<
-  // LabelPointType,vcl_pow(2.0,itkGetStaticConstMacro(ImageDimension))>
+  // LabelPointType,std::pow(2.0,itkGetStaticConstMacro(ImageDimension))>
   // BoundingBoxVerticesType;
   typedef std::vector< LabelPointType > BoundingBoxVerticesType;
 
@@ -193,7 +192,7 @@ public:
       m_Orientation = 0;
       LabelPointType emptyPoint;
       emptyPoint.Fill(0);
-      unsigned int numberOfVertices = (unsigned int)vcl_pow( (double)2, (int)ImageDimension );
+      unsigned int numberOfVertices = (unsigned int)std::pow( (double)2, (int)ImageDimension );
       m_OrientedBoundingBoxVertices.resize(numberOfVertices, emptyPoint);
       m_OrientedBoundingBoxVolume = 0;
       m_OrientedBoundingBoxSize.Fill(0);
