@@ -117,7 +117,7 @@ public:
 protected:
   NeuralNetworkFileReader();
   ~NeuralNetworkFileReader();
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
 
