@@ -78,7 +78,7 @@ JPEG2000ImageIO::JPEG2000ImageIO()
   this->SetNumberOfDimensions(2); // JPEG2000 is 2D. (by now...)
   this->SetNumberOfComponents(1);
 
-  this->m_Internal->m_Dinfo = NULL;
+  this->m_Internal->m_Dinfo = ITK_NULLPTR;
 
   this->m_Internal->m_TileWidth = 0;
   this->m_Internal->m_TileHeight = 0;
@@ -164,9 +164,9 @@ void JPEG2000ImageIO::ReadImageInformation()
 
   opj_stream_t *cio = opj_stream_create_default_file_stream(l_file, true);
 
-  this->m_Internal->m_Dinfo = NULL;  /* handle to a decompressor */
+  this->m_Internal->m_Dinfo = ITK_NULLPTR;  /* handle to a decompressor */
 
-  opj_image_t *l_image = NULL;
+  opj_image_t *l_image = ITK_NULLPTR;
 
   /* decode the code-stream */
   /* ---------------------- */
@@ -382,7 +382,7 @@ void JPEG2000ImageIO::ReadImageInformation()
   if ( this->m_Internal->m_Dinfo )
     {
     opj_destroy_codec(this->m_Internal->m_Dinfo);
-    this->m_Internal->m_Dinfo = NULL;
+    this->m_Internal->m_Dinfo = ITK_NULLPTR;
     }
 
   if( l_image )
@@ -417,9 +417,9 @@ void JPEG2000ImageIO::Read(void *buffer)
       << "Reason: opj_stream_create_default_file_stream returns NULL" );
     }
 
-  this->m_Internal->m_Dinfo  = NULL;  /* handle to a decompressor */
+  this->m_Internal->m_Dinfo  = ITK_NULLPTR;  /* handle to a decompressor */
 
-  opj_image_t *l_image = NULL;
+  opj_image_t *l_image = ITK_NULLPTR;
 
   /* decode the code-stream */
   /* ---------------------- */
@@ -479,7 +479,6 @@ void JPEG2000ImageIO::Read(void *buffer)
         << "Reason: "
         << "Unknown decode format: "
         << this->m_Internal->m_DecompressionParameters.decod_format );
-      return;
 }
   /* catch events using our callbacks and give a local context */
 
@@ -514,7 +513,7 @@ void JPEG2000ImageIO::Read(void *buffer)
   if ( !bResult )
     {
     opj_destroy_codec(this->m_Internal->m_Dinfo);
-    this->m_Internal->m_Dinfo = NULL;
+    this->m_Internal->m_Dinfo = ITK_NULLPTR;
     opj_stream_destroy(l_stream);
     fclose(l_file);
     itkExceptionMacro(
@@ -561,7 +560,7 @@ void JPEG2000ImageIO::Read(void *buffer)
   if ( !bResult )
     {
     opj_destroy_codec(this->m_Internal->m_Dinfo);
-    this->m_Internal->m_Dinfo = NULL;
+    this->m_Internal->m_Dinfo = ITK_NULLPTR;
     opj_stream_destroy(l_stream);
     fclose(l_file);
     itkExceptionMacro(
@@ -739,7 +738,7 @@ void JPEG2000ImageIO::Read(void *buffer)
   if ( !l_image )
     {
     opj_destroy_codec(this->m_Internal->m_Dinfo);
-    this->m_Internal->m_Dinfo = NULL;
+    this->m_Internal->m_Dinfo = ITK_NULLPTR;
     opj_stream_destroy(l_stream);
     fclose(l_file);
     itkExceptionMacro(
@@ -756,7 +755,7 @@ void JPEG2000ImageIO::Read(void *buffer)
   if ( this->m_Internal->m_Dinfo )
     {
     opj_destroy_codec(this->m_Internal->m_Dinfo);
-    this->m_Internal->m_Dinfo = NULL;
+    this->m_Internal->m_Dinfo = ITK_NULLPTR;
     }
 
   if( l_image )
@@ -870,7 +869,6 @@ JPEG2000ImageIO
       << "Error: Tile offset dimension is unnappropriate -->"
       << "  TX0(" << parameters.cp_tx0 << ") <= IMG_X0( " << parameters.image_offset_x0
       << ") TYO(" << parameters.cp_ty0 << ") <= IMG_Y0( " << parameters.image_offset_y0 << ") " );
-      return;
     }
 
   for ( int i = 0; i < parameters.numpocs; i++ )
@@ -885,7 +883,7 @@ JPEG2000ImageIO
     }
 
   /* Create comment for codestream */
-  if ( parameters.cp_comment == NULL )
+  if ( parameters.cp_comment == ITK_NULLPTR )
     {
     const char   comment[] = "Created by OpenJPEG version ";
     const SizeValueType clen = strlen(comment);
@@ -1039,7 +1037,7 @@ JPEG2000ImageIO
   itkDebugMacro(<< " END COPY BUFFER");
 //--------------------------------------------------------------------
 
-  opj_codec_t *cinfo = NULL;
+  opj_codec_t *cinfo = ITK_NULLPTR;
   if ( extension == ".j2k" )
     {
     cinfo = opj_create_compress(CODEC_J2K);
