@@ -54,12 +54,12 @@ protected:
 
   typedef const ReconstructionFilterType * ReconstructionFilterPointer;
 
-  void Execute(itk::Object * caller, const itk::EventObject & event )
+  virtual void Execute(itk::Object * caller, const itk::EventObject & event ) ITK_OVERRIDE
     {
     Execute( ( const itk::Object * )caller, event);
     }
 
-  void Execute( const itk::Object * caller, const itk::EventObject & event )
+  virtual void Execute( const itk::Object * caller, const itk::EventObject & event ) ITK_OVERRIDE
     {
     ReconstructionFilterPointer reconstructor = dynamic_cast< ReconstructionFilterPointer >( caller );
 
