@@ -104,8 +104,6 @@ int itkFastSymmetricForcesDemonsRegistrationFilterTest(int, char* [] )
   typedef itk::Image<PixelType,ImageDimension>  ImageType;
   typedef itk::Vector<float,ImageDimension>     VectorType;
   typedef itk::Image<VectorType,ImageDimension> FieldType;
-  typedef itk::Image<VectorType::ValueType,
-      ImageDimension>                           FloatImageType;
   typedef ImageType::IndexType                  IndexType;
   typedef ImageType::SizeType                   SizeType;
   typedef ImageType::RegionType                 RegionType;
@@ -269,7 +267,7 @@ int itkFastSymmetricForcesDemonsRegistrationFilterTest(int, char* [] )
   bool passed = true;
   try
     {
-    registrator->SetInput( NULL );
+    registrator->SetInput( ITK_NULLPTR );
     registrator->SetNumberOfIterations( 2 );
     registrator->Update();
     }
@@ -294,7 +292,7 @@ int itkFastSymmetricForcesDemonsRegistrationFilterTest(int, char* [] )
   try
     {
     registrator->SetInput( caster->GetOutput() );
-    registrator->SetMovingImage( NULL );
+    registrator->SetMovingImage( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject & err )
@@ -318,7 +316,7 @@ int itkFastSymmetricForcesDemonsRegistrationFilterTest(int, char* [] )
     {
     fptr = dynamic_cast<FunctionType *>(
       registrator->GetDifferenceFunction().GetPointer() );
-    fptr->SetMovingImageInterpolator( NULL );
+    fptr->SetMovingImageInterpolator( ITK_NULLPTR );
     registrator->SetInput( initField );
     registrator->Update();
     }
