@@ -57,7 +57,7 @@ public:
    * CreateAnother method will clone the existing instance of this type,
    * including its internal member variables.
    */
-  virtual::itk::LightObject::Pointer CreateAnother(void) const;
+  virtual::itk::LightObject::Pointer CreateAnother(void) const ITK_OVERRIDE;
 
   /**
    * Default constructor only clears the internal storage
@@ -71,7 +71,7 @@ public:
   Element3DC0LinearTetrahedronStrain(NodeIDType ns_[], Material::ConstPointer p_);
 
 protected:
-  virtual void PrintSelf(std::ostream& os, Indent indent) const;
+  virtual void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 };  // class Element3DC0LinearTetrahedronStrain
 
