@@ -68,7 +68,7 @@ public:
 
   /** CreateAnother method will clone the existing instance of this type,
    * including its internal member variables. */
-  virtual::itk::LightObject::Pointer CreateAnother(void) const;
+  virtual::itk::LightObject::Pointer CreateAnother(void) const ITK_OVERRIDE;
 
   /**
    * \class MFCTerm
@@ -161,7 +161,7 @@ public:
 //  friend class Solver;
 
 protected:
-  virtual void PrintSelf(std::ostream& os, Indent indent) const;
+  virtual void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
   // private:  // FIXME: CrankNicolsonSolver class, which is derived from Solver
   // class also needs access to Index.
