@@ -640,7 +640,7 @@ bool CheckDisplacements(itk::fem::Solver & S, int s, char comment, double *expec
          d++ )
       {
       double result = S.GetSolution(dof);
-      if( vcl_fabs(result - expectedResults[index]) > tolerance )
+      if( std::fabs(result - expectedResults[index]) > tolerance )
         {
         std::cout << "Error: Result (" << result << ") expected (" << expectedResults[index] << ") with tolerance ("
                   << tolerance << ")" << std::endl;
