@@ -58,7 +58,7 @@ protected:
   ~LearningFunctionBase() {};
 
   /** Method to print the object. */
-  virtual void PrintSelf( std::ostream& os, Indent indent ) const
+  virtual void PrintSelf( std::ostream& os, Indent indent ) const ITK_OVERRIDE
     {
     Superclass::PrintSelf( os, indent );
     os << indent << "LearningFunctionBase(" << this << ")" << std::endl;
