@@ -125,7 +125,7 @@ protected:
   ~WeightSetBase();
 
   /** Method to print the object. */
-  virtual void PrintSelf( std::ostream& os, Indent indent ) const;
+  virtual void PrintSelf( std::ostream& os, Indent indent ) const ITK_OVERRIDE;
 
   typename RandomVariateGeneratorType::Pointer m_RandomGenerator;
 
