@@ -58,7 +58,7 @@ public:
 protected:
   CostFunctionTemplate() {}
   virtual ~CostFunctionTemplate() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   CostFunctionTemplate(const Self &);   //purposely not implemented
