@@ -73,7 +73,7 @@ public:
   itkGetConstMacro(UseUnitLengthGradient, bool);
 
   /** Start optimization. */
-  void StartOptimization();
+  virtual void StartOptimization() ITK_OVERRIDE;
 
   /** Set it to the Fletch-Reeves optimizer */
   void SetToFletchReeves();
@@ -85,7 +85,7 @@ protected:
   FRPROptimizer();
   virtual ~FRPROptimizer();
 
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Get the value of the n-dimensional cost function at this scalar step
    * distance along the current line direction from the current line origin.
