@@ -70,7 +70,7 @@ public:
 protected:
   MultipleValuedNonLinearOptimizer();
   virtual ~MultipleValuedNonLinearOptimizer() {}
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   CostFunctionPointer m_CostFunction;
 
