@@ -28,7 +28,8 @@ namespace itk
  * ************************* Constructor ************************
  */
 SPSAOptimizer
-::SPSAOptimizer()
+::SPSAOptimizer():
+  m_Stop(false)
 {
   itkDebugMacro("Constructor");
 
@@ -289,7 +290,7 @@ double SPSAOptimizer
 ::Compute_a(SizeValueType k) const
 {
   return static_cast< double >(
-           m_Sa / vcl_pow(m_A + k + 1, m_Alpha) );
+           m_Sa / std::pow(m_A + k + 1, m_Alpha) );
 } // end Compute_a
 
 /**
@@ -303,7 +304,7 @@ double SPSAOptimizer
 ::Compute_c(SizeValueType k) const
 {
   return static_cast< double >(
-           m_Sc / vcl_pow(k + 1, m_Gamma) );
+           m_Sc / std::pow(k + 1, m_Gamma) );
 } // end Compute_c
 
 /**
@@ -482,14 +483,14 @@ SPSAOptimizer::GuessParameters(
     this->ComputeGradient(initialPosition, m_Gradient);
     for ( unsigned int j = 0; j < spaceDimension; j++ )
       {
-      averageAbsoluteGradient[j] += vcl_fabs(m_Gradient[j]);
+      averageAbsoluteGradient[j] += std::fabs(m_Gradient[j]);
       }
     } // end for ++n
   averageAbsoluteGradient /= static_cast< double >( numberOfGradientEstimates );
 
   /** Set a in order to make the first steps approximately have an
     initialStepSize */
-  this->SetSa( initialStepSize * vcl_pow(m_A + 1.0, m_Alpha)
+  this->SetSa( initialStepSize * std::pow(m_A + 1.0, m_Alpha)
                / averageAbsoluteGradient.max_value() );
 } //end GuessParameters
 
