@@ -98,7 +98,7 @@ protected:
 
   ~ConvergenceMonitoringFunction() {}
 
-  void PrintSelf( std::ostream & os, Indent indent ) const
+  virtual void PrintSelf( std::ostream & os, Indent indent ) const ITK_OVERRIDE
     {
     Superclass::PrintSelf( os, indent );
 
