@@ -81,25 +81,25 @@ namespace itk
  *
  * \ingroup ITKOptimizersv4
  */
-template<unsigned int TFixedDimension, unsigned int TMovingDimension, class TVirtualImage = Image<typename ObjectToObjectMetricBase::ParametersValueType, TFixedDimension> >
-class ITK_EXPORT ObjectToObjectMetric:
-  public ObjectToObjectMetricBase
+template<unsigned int TFixedDimension, unsigned int TMovingDimension, typename TVirtualImage = Image<double, TFixedDimension>, class TInternalComputationValueType=double>
+class ObjectToObjectMetric:
+  public ObjectToObjectMetricBaseTemplate< TInternalComputationValueType >
 {
 public:
   /** Standard class typedefs. */
-  typedef ObjectToObjectMetric         Self;
-  typedef ObjectToObjectMetricBase     Superclass;
-  typedef SmartPointer< Self >         Pointer;
-  typedef SmartPointer< const Self >   ConstPointer;
+  typedef ObjectToObjectMetric                                              Self;
+  typedef ObjectToObjectMetricBaseTemplate< TInternalComputationValueType > Superclass;
+  typedef SmartPointer< Self >                                              Pointer;
+  typedef SmartPointer< const Self >                                        ConstPointer;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(ObjectToObjectMetric, ObjectToObjectMetricBase);
+  itkTypeMacro(ObjectToObjectMetric, ObjectToObjectMetricBaseTemplate);
 
   /** Type used for representing object components  */
-  typedef typename Superclass::ParametersValueType            CoordinateRepresentationType;
+  typedef TInternalComputationValueType            CoordinateRepresentationType;
 
   /** Type for internal computations */
-  typedef typename Superclass::InternalComputationValueType   InternalComputationValueType;
+  typedef TInternalComputationValueType            InternalComputationValueType;
 
   /**  Type of the measure. */
   typedef typename Superclass::MeasureType            MeasureType;
@@ -110,11 +110,12 @@ public:
 
   /**  Type of the parameters. */
   typedef typename Superclass::ParametersType         ParametersType;
-  typedef typename Superclass::ParametersValueType    ParametersValueType;
   typedef typename Superclass::NumberOfParametersType NumberOfParametersType;
 
+  typedef typename Superclass::GradientSourceType     GradientSourceType;
+
   /** Dimension type */
-  typedef SizeValueType                       DimensionType;
+  typedef SizeValueType                               DimensionType;
 
   /** Object dimension accessors */
   itkStaticConstMacro(FixedDimension, DimensionType, TFixedDimension);
@@ -140,8 +141,8 @@ public:
   typedef typename VirtualPointSetType::Pointer                                 VirtualPointSetPointer;
 
   /**  Type of the Transform Base classes */
-  typedef Transform<ParametersValueType, TVirtualImage::ImageDimension, TMovingDimension> MovingTransformType;
-  typedef Transform<ParametersValueType, TVirtualImage::ImageDimension, TFixedDimension>  FixedTransformType;
+  typedef Transform<TInternalComputationValueType, TVirtualImage::ImageDimension, TMovingDimension> MovingTransformType;
+  typedef Transform<TInternalComputationValueType, TVirtualImage::ImageDimension, TFixedDimension>  FixedTransformType;
 
   typedef typename FixedTransformType::Pointer         FixedTransformPointer;
   typedef typename FixedTransformType::InputPointType  FixedInputPointType;
@@ -168,19 +169,19 @@ public:
   virtual void SetParameters( ParametersType & params );
   virtual const ParametersType & GetParameters() const;
   virtual bool HasLocalSupport() const;
-  virtual void UpdateTransformParameters( const DerivativeType & derivative, ParametersValueType factor);
+  virtual void UpdateTransformParameters( const DerivativeType & derivative, TInternalComputationValueType factor);
 
   /** Connect the fixed transform. */
   itkSetObjectMacro(FixedTransform, FixedTransformType);
 
   /** Get a pointer to the fixed transform.  */
-  itkGetConstObjectMacro(FixedTransform, FixedTransformType);
+  itkGetModifiableObjectMacro(FixedTransform, FixedTransformType);
 
   /** Connect the moving transform. */
   itkSetObjectMacro(MovingTransform, MovingTransformType);
 
   /** Get a pointer to the moving transform.  */
-  itkGetConstObjectMacro(MovingTransform, MovingTransformType);
+  itkGetModifiableObjectMacro(MovingTransform, MovingTransformType);
 
   /** Connect the moving transform using a backwards-compatible name.
    * This assigns the input transform to the moving transform. */
@@ -246,7 +247,7 @@ public:
    *  the m_VirtualImage buffered region. */
   const VirtualRegionType   &  GetVirtualRegion( void ) const;
 
-  itkGetConstObjectMacro( VirtualImage, VirtualImageType );
+  itkGetModifiableObjectMacro(VirtualImage, VirtualImageType );
 
   /** Computes an offset for accessing parameter data from a virtual domain
    * index. Relevant for metrics with local-support transforms, to access
@@ -294,7 +295,7 @@ protected:
    *  If the moving transform is a CompositeTransform, the routine will check if the
    *  first (last to be added) transform is a DisplacementFieldTransform, and if so return it.
    *  Otherwise, return NULL. */
-  MovingDisplacementFieldTransformType * GetMovingDisplacementFieldTransform() const;
+  const MovingDisplacementFieldTransformType * GetMovingDisplacementFieldTransform() const;
 
   /** Check that the number of valid points is above a default
    * minimum (zero). If not, then return false, and assign to 'value' a value
