@@ -59,15 +59,15 @@ public:
     m_Parameters.Fill( 0 );
   }
 
-  void Initialize(void) throw ( itk::ExceptionObject ) {}
+  virtual void Initialize(void) throw ( itk::ExceptionObject ) ITK_OVERRIDE {}
 
-  virtual void GetDerivative( DerivativeType & derivative ) const
+  virtual void GetDerivative( DerivativeType & derivative ) const ITK_OVERRIDE
     {
     derivative.Fill( itk::NumericTraits< ParametersValueType >::Zero );
     }
 
   void GetValueAndDerivative( MeasureType & value,
-                              DerivativeType & derivative ) const
+                              DerivativeType & derivative ) const ITK_OVERRIDE
   {
     if( derivative.Size() != 2 )
       derivative.SetSize(2);
@@ -93,7 +93,7 @@ public:
     std::cout << "derivative: " << derivative << std::endl;
   }
 
-  MeasureType  GetValue() const
+  virtual MeasureType  GetValue() const ITK_OVERRIDE
   {
     double x = m_Parameters[0];
     double y = m_Parameters[1];
@@ -102,34 +102,34 @@ public:
     return metric;
   }
 
-  void UpdateTransformParameters( const DerivativeType & update, ParametersValueType )
+  virtual void UpdateTransformParameters( const DerivativeType & update, ParametersValueType ) ITK_OVERRIDE
   {
     m_Parameters += update;
   }
 
-  unsigned int GetNumberOfParameters(void) const
+  virtual unsigned int GetNumberOfParameters(void) const ITK_OVERRIDE
   {
     return SpaceDimension;
   }
 
-  virtual bool HasLocalSupport() const
+  virtual bool HasLocalSupport() const ITK_OVERRIDE
     {
     return false;
     }
 
-  unsigned int GetNumberOfLocalParameters() const
+  virtual unsigned int GetNumberOfLocalParameters() const ITK_OVERRIDE
   {
     return SpaceDimension;
   }
 
   /* These Set/Get methods are only needed for this test derivation that
    * isn't using a transform */
-  void SetParameters( ParametersType & parameters )
+  virtual void SetParameters( ParametersType & parameters ) ITK_OVERRIDE
   {
     m_Parameters = parameters;
   }
 
-  const ParametersType & GetParameters() const
+  virtual const ParametersType & GetParameters() const ITK_OVERRIDE
   {
     return m_Parameters;
   }
@@ -194,9 +194,7 @@ int itkMultiStartOptimizerv4Test(int, char* [] )
   std::cout << "MultiStart  Optimizer Test ";
   std::cout << std::endl << std::endl;
 
-  typedef  itk::MultiStartOptimizerv4  OptimizerType;
-
-  typedef OptimizerType::ScalesType             ScalesType;
+  typedef itk::MultiStartOptimizerv4 OptimizerType;
 
   // Declaration of a itkOptimizer
   OptimizerType::Pointer  itkOptimizer = OptimizerType::New();
