@@ -182,7 +182,7 @@ int itkRegistrationParameterScalesFromJacobianTest(int , char* [])
   bool jacobianPass = true;
   for (itk::SizeValueType p = 0; p < jacobianScales.GetSize(); p++)
     {
-    if (vcl_abs((jacobianScales[p] - theoreticalJacobianScales[p])
+    if (std::abs((jacobianScales[p] - theoreticalJacobianScales[p])
       / theoreticalJacobianScales[p]) > 0.01 )
       {
       jacobianPass = false;
@@ -230,14 +230,14 @@ int itkRegistrationParameterScalesFromJacobianTest(int , char* [])
     {
     for (FloatType y=lowerPoint[1]; y<=upperPoint[1]; y+=upperPoint[1]-lowerPoint[1])
       {
-      theoreticalStepScale += vcl_sqrt(x*x + y*y);
+      theoreticalStepScale += std::sqrt(x*x + y*y);
       count++;
       }
     }
   theoreticalStepScale /= count;
 
   bool stepScalePass = false;
-  if (vcl_abs( (stepScale - theoreticalStepScale)/theoreticalStepScale ) < 0.01)
+  if (std::abs( (stepScale - theoreticalStepScale)/theoreticalStepScale ) < 0.01)
     {
     stepScalePass = true;
     }
@@ -285,7 +285,7 @@ int itkRegistrationParameterScalesFromJacobianTest(int , char* [])
   bool displacementPass = true;
   for (itk::SizeValueType p = 0; p < theoreticalLocalScales.GetSize(); p++)
     {
-    if (vcl_abs((localScales[p] - theoreticalLocalScales[p])
+    if (std::abs((localScales[p] - theoreticalLocalScales[p])
       / theoreticalLocalScales[p]) > 0.01 )
       {
       displacementPass = false;
@@ -311,8 +311,8 @@ int itkRegistrationParameterScalesFromJacobianTest(int , char* [])
   std::cout << "The learning rate of Jacobian for the displacement field transform = " << localLearningRate << std::endl;
 
   bool localStepScalePass = false;
-  FloatType theoreticalLocalStepScale = vcl_sqrt(2.0);
-  if (vcl_abs( (localStepScale - theoreticalLocalStepScale)
+  FloatType theoreticalLocalStepScale = std::sqrt(2.0);
+  if (std::abs( (localStepScale - theoreticalLocalStepScale)
     /theoreticalLocalStepScale ) < 0.01)
     {
     localStepScalePass = true;
