@@ -131,7 +131,7 @@ public:
 protected:
   MixtureModelComponentBase();
   virtual ~MixtureModelComponentBase();
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** stores the pointer to the membership function.
    * subclasses use this function to store their membership function
