@@ -72,16 +72,16 @@ public:
 
   /** Return the number of parameters.  For a univariate Student-t
    * distribution, the number of parameters is 1 (degrees of freedom) */
-  virtual SizeValueType GetNumberOfParameters() const { return 1; }
+  virtual SizeValueType GetNumberOfParameters() const ITK_OVERRIDE { return 1; }
 
   /** Evaluate the probability density function (pdf). The parameters
    * of the distribution are  assigned via SetParameters().  */
-  virtual double EvaluatePDF(double x) const;
+  virtual double EvaluatePDF(double x) const ITK_OVERRIDE;
 
   /** Evaluate the probability density function (pdf). The parameters
    * for the distribution are passed as a parameters vector. The
    * ordering of the parameters is (degrees of freedom). */
-  virtual double EvaluatePDF(double x, const ParametersType &) const;
+  virtual double EvaluatePDF(double x, const ParametersType &) const ITK_OVERRIDE;
 
   /** Evaluate the probability density function (pdf). The parameters
    * of the distribution are passed as separate parameters. */
@@ -89,12 +89,12 @@ public:
 
   /** Evaluate the cumulative distribution function (cdf). The parameters
    * of the distribution are  assigned via SetParameters().  */
-  virtual double EvaluateCDF(double x) const;
+  virtual double EvaluateCDF(double x) const ITK_OVERRIDE;
 
   /** Evaluate the cumulative distribution function (cdf). The parameters
    * for the distribution are passed as a parameters vector. The
    * ordering of the parameters is (degreesOfFreedom). */
-  virtual double EvaluateCDF(double x, const ParametersType &) const;
+  virtual double EvaluateCDF(double x, const ParametersType &) const ITK_OVERRIDE;
 
   /** Evaluate the cumulative distribution function (cdf). The parameters
    * of the distribution are passed as separate parameters. */
@@ -103,13 +103,13 @@ public:
   /** Evaluate the inverse cumulative distribution function (inverse
    * cdf).  Parameter p must be between 0.0 and 1.0. The parameters
    * of the distribution are  assigned via SetParameters().  */
-  virtual double EvaluateInverseCDF(double p) const;
+  virtual double EvaluateInverseCDF(double p) const ITK_OVERRIDE;
 
   /** Evaluate the inverse cumulative distribution function (inverse
    * cdf).  Parameter p must be between 0.0 and 1.0.  The parameters
    * for the distribution are passed as a parameters vector. The
    * ordering of the parameters is (degrees of freedom). */
-  virtual double EvaluateInverseCDF(double p, const ParametersType &) const;
+  virtual double EvaluateInverseCDF(double p, const ParametersType &) const ITK_OVERRIDE;
 
   /** Evaluate the inverse cumulative distribution function (inverse
    * cdf).  Parameter p must be between 0.0 and 1.0.  The parameters
@@ -125,18 +125,18 @@ public:
   virtual SizeValueType GetDegreesOfFreedom() const;
 
   /** Does the Student-t distribution have a mean? */
-  virtual bool HasMean() const { return true; }
+  virtual bool HasMean() const ITK_OVERRIDE { return true; }
 
   /** Get the mean of the distribution. */
-  virtual double GetMean() const;
+  virtual double GetMean() const ITK_OVERRIDE;
 
   /** Does the Student-t distribution have a variance? Variance is
    * only defined for degrees of freedom greater than 2 */
-  virtual bool HasVariance() const;
+  virtual bool HasVariance() const ITK_OVERRIDE;
 
   /** Get the variance of the distribution. If the variance does not exist,
    * then quiet_NaN is returned. */
-  virtual double GetVariance() const;
+  virtual double GetVariance() const ITK_OVERRIDE;
 
   /** Static method to evaluate the probability density function (pdf)
    * of a Student-t with a specified number of degrees of freedom. The
@@ -200,7 +200,7 @@ protected:
   TDistribution(void);
   virtual ~TDistribution(void) {}
 
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   TDistribution(const Self &);  //purposely not implemented
