@@ -52,34 +52,45 @@ public:
   itkTypeMacro(WeightedMeanSampleFilter, MeanSampleFilter);
   itkNewMacro(Self);
 
-  /** Traits derived from the base class */
+  /** Types derived from the base class */
   typedef typename Superclass::SampleType                     SampleType;
-  typedef typename Superclass::MeasurementType                MeasurementType;
   typedef typename Superclass::MeasurementVectorType          MeasurementVectorType;
   typedef typename Superclass::MeasurementVectorSizeType      MeasurementVectorSizeType;
-  typedef typename Superclass::MeasurementVectorDecoratedType MeasurementVectorDecoratedType;
-  typedef typename Superclass::OutputType                     OutputType;
-  typedef typename Superclass::MeasurementRealType            MeasurementRealType;
-  typedef typename Superclass::MeasurementVectorRealType      MeasurementVectorRealType;
+  typedef typename Superclass::MeasurementType                MeasurementType;
 
-  /** Array typedef for weights */
-  typedef Array< double > WeightArrayType;
+  /** Types derived from the base class */
+  typedef typename Superclass::MeasurementVectorRealType      MeasurementVectorRealType;
+  typedef typename Superclass::MeasurementRealType            MeasurementRealType;
+
+
+  /** Type of weight values */
+  typedef double WeightValueType;
+
+
+  /** Array type for weights */
+  typedef Array< WeightValueType > WeightArrayType;
 
   /** Type of DataObjects to use for the weight array type */
   typedef SimpleDataObjectDecorator< WeightArrayType > InputWeightArrayObjectType;
 
-  /** Method to set the input value of the weight array */
+  /** Method to set/get the input value of the weight array */
   itkSetGetDecoratedInputMacro(Weights, WeightArrayType);
 
-  /** Weight calculation function typedef */
-  typedef FunctionBase< MeasurementVectorType, double > WeightingFunctionType;
+
+  /** Weight calculation function type */
+  typedef FunctionBase< MeasurementVectorType, WeightValueType > WeightingFunctionType;
 
   /** Type of DataObjects to use for Weight function */
   typedef DataObjectDecorator< WeightingFunctionType > InputWeightingFunctionObjectType;
 
-  /** Method to set the weighting function */
+  /** Method to set/get the weighting function */
   itkSetGetDecoratedObjectInputMacro(WeightingFunction, WeightingFunctionType);
 
+
+  /** Types derived from the base class */
+  typedef typename Superclass::MeasurementVectorDecoratedType MeasurementVectorDecoratedType;
+  typedef typename Superclass::OutputType                     OutputType;
+
 protected:
   WeightedMeanSampleFilter();
   virtual ~WeightedMeanSampleFilter();
