@@ -78,7 +78,7 @@ public:
   typedef double OutputType;
 
   /**Evaluate at the specified input position */
-  OutputType Evaluate( const InputType & itkNotUsed( input ) ) const
+  virtual OutputType Evaluate( const InputType & itkNotUsed( input ) ) const ITK_OVERRIDE
     {
     MeasurementVectorType2 measurements;
     // set the weight factor of the measurment
@@ -156,7 +156,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
     std::cout << "Expected exception caught: " << excp << std::endl;
     }
 
-  if ( filter->GetInput() != NULL )
+  if ( filter->GetInput() != ITK_NULLPTR )
     {
     std::cerr << "GetInput() should return NULL if the input \
                      has not been set" << std::endl;
@@ -212,7 +212,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
 
   for ( unsigned int i = 0; i < MeasurementVectorSize2; i++ )
     {
-    if ( vcl_abs( meanExpected33[i] - mean[i] ) > epsilon )
+    if ( std::abs( meanExpected33[i] - mean[i] ) > epsilon )
       {
       std::cerr << "The computed mean value is incorrrect" << std::endl;
       return EXIT_FAILURE;
@@ -236,7 +236,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
   for ( unsigned int i = 0; i < MeasurementVectorSize2; i++ )
   {
   for ( unsigned int j = 0; j < MeasurementVectorSize2; j++ )
-    if ( vcl_abs( matrixExpected33[i][j] - matrix[i][j] ) > epsilon )
+    if ( std::abs( matrixExpected33[i][j] - matrix[i][j] ) > epsilon )
       {
       std::cerr << "Computed covariance matrix value is incorrrect" << std::endl;
       return EXIT_FAILURE;
@@ -278,7 +278,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
 
   for ( unsigned int i = 0; i < MeasurementVectorSize2; i++ )
     {
-    if ( vcl_abs( meanExpected3[i] - mean[i] ) > epsilon )
+    if ( std::abs( meanExpected3[i] - mean[i] ) > epsilon )
       {
       std::cerr << "The computed mean value is incorrrect" << std::endl;
       return EXIT_FAILURE;
@@ -303,7 +303,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
     {
     for ( unsigned int j = 0; j < MeasurementVectorSize2; j++ )
       {
-      if ( vcl_abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
+      if ( std::abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
         {
         std::cerr << "Computed covariance matrix value is incorrrect" << std::endl;
         return EXIT_FAILURE;
@@ -331,7 +331,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
 
   for ( unsigned int i = 0; i < MeasurementVectorSize2; i++ )
     {
-    if ( vcl_abs( meanExpected3[i] - mean[i] ) > epsilon )
+    if ( std::abs( meanExpected3[i] - mean[i] ) > epsilon )
       {
       std::cerr << "The computed mean value is incorrrect" << std::endl;
       return EXIT_FAILURE;
@@ -342,7 +342,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
     {
     for ( unsigned int j = 0; j < MeasurementVectorSize2; j++ )
       {
-      if ( vcl_abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
+      if ( std::abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
         {
         std::cerr << "Computed covariance matrix value is incorrrect" << std::endl;
         return EXIT_FAILURE;
@@ -373,7 +373,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
 
   for ( unsigned int i = 0; i < MeasurementVectorSize2; i++ )
     {
-    if ( vcl_abs( meanExpected3[i] - mean[i] ) > epsilon )
+    if ( std::abs( meanExpected3[i] - mean[i] ) > epsilon )
       {
       std::cerr << "The computed mean value is incorrrect" << std::endl;
       return EXIT_FAILURE;
@@ -384,7 +384,7 @@ int itkWeightedCovarianceSampleFilterTest2(int, char* [] )
     {
     for ( unsigned int j = 0; j < MeasurementVectorSize2; j++ )
       {
-      if ( vcl_abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
+      if ( std::abs( matrixExpected[i][j] - matrix[i][j] ) > epsilon )
         {
         std::cerr << "Computed covariance matrix value is incorrrect" << std::endl;
         return EXIT_FAILURE;
