@@ -125,7 +125,7 @@ void GenerateImages( const typename MovingImageType::SizeType & size )
     d += displacement;
     const double x = d[0];
     const double y = d[1];
-    const double value = 200.0 * vcl_exp( - ( x*x + y*y )/(s*s) );
+    const double value = 200.0 * std::exp( - ( x*x + y*y )/(s*s) );
     ri.Set( static_cast<typename MovingImageType::PixelType>(value) );
     ++ri;
   }
@@ -138,7 +138,7 @@ void GenerateImages( const typename MovingImageType::SizeType & size )
     d = p-center;
     const double x = d[0];
     const double y = d[1];
-    const double value = 200.0 * vcl_exp( - ( x*x + y*y )/(s*s) );
+    const double value = 200.0 * std::exp( - ( x*x + y*y )/(s*s) );
     ti.Set( static_cast<typename FixedImageType::PixelType>(value) );
     ++ti;
   }
