@@ -93,7 +93,7 @@ int itkMutualInformationMetricTest(int, char* [] )
     d += displacement;
     const double x = d[0];
     const double y = d[1];
-    ri.Set( (unsigned char) ( 200.0 * vcl_exp( - ( x*x + y*y )/(s*s) ) ) );
+    ri.Set( (unsigned char) ( 200.0 * std::exp( - ( x*x + y*y )/(s*s) ) ) );
     ++ri;
     }
 
@@ -106,7 +106,7 @@ int itkMutualInformationMetricTest(int, char* [] )
     d = p-center;
     const double x = d[0];
     const double y = d[1];
-    ti.Set( (unsigned char) ( 200.0 * vcl_exp( - ( x*x + y*y )/(s*s) ) ) );
+    ti.Set( (unsigned char) ( 200.0 * std::exp( - ( x*x + y*y )/(s*s) ) ) );
     ++ti;
     }
 
@@ -254,7 +254,7 @@ int itkMutualInformationMetricTest(int, char* [] )
 
   std::cout << "Try causing a exception by making fixed image NULL";
   std::cout << std::endl;
-  metric->SetFixedImage( NULL );
+  metric->SetFixedImage( ITK_NULLPTR );
   try
     {
     metric->Initialize();
