@@ -49,8 +49,8 @@ namespace itk
  * \ingroup FiniteDifferenceFunctions
  * \ingroup ITKFEMRegistration
  */
-template< class TFixedImage, class TMovingImage, class TDisplacementField >
-class ITK_EXPORT NCCRegistrationFunction:
+template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
+class NCCRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage, TDisplacementField >
 {
