@@ -82,7 +82,9 @@ public:
   typedef typename TMattesMutualInformationMetric::JacobianType             JacobianType;
 
 protected:
-  MattesMutualInformationImageToImageMetricv4GetValueAndDerivativeThreader() {}
+  MattesMutualInformationImageToImageMetricv4GetValueAndDerivativeThreader() :
+    m_MattesAssociate(ITK_NULLPTR)
+  {}
 
   virtual void BeforeThreadedExecution();
 
@@ -102,14 +104,20 @@ protected:
         const MovingImageGradientType &   mappedMovingImageGradient,
         MeasureType &                     metricValueReturn,
         DerivativeType &                  localDerivativeReturn,
-        const ThreadIdType                threadID ) const;
+        const ThreadIdType                threadId ) const;
 
-  /** Compute PDF derivative contribution for each parameter. */
-  virtual void ComputePDFDerivatives(const ThreadIdType &    threadID,
+  /** Compute PDF derivative contribution for each parameter of a global support transform type. */
+  virtual void ComputePDFDerivativesGlobalSupportTransform(const ThreadIdType &    threadId,
                              const OffsetValueType &         fixedImageParzenWindowIndex,
                              const JacobianType &            jacobian,
                              const OffsetValueType &         pdfMovingIndex,
                              const MovingImageGradientType & movingGradient,
+                             const PDFValueType &            cubicBSplineDerivativeValue) const;
+
+  /** Compute PDF derivative contribution for each parameter of a displacement field. */
+  virtual void ComputePDFDerivativesLocalSupportTransform(
+                             const JacobianType &            jacobian,
+                             const MovingImageGradientType & movingGradient,
                              const PDFValueType &            cubicBSplineDerivativeValue,
                              DerivativeValueType *           localSupportDerivativeResultPtr) const;
 
