@@ -37,12 +37,12 @@ protected:
 
 public:
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  virtual void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *) caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  virtual void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     if( typeid( event ) != typeid( itk::IterationEvent ) )
       {
@@ -103,8 +103,8 @@ int itkEuclideanDistancePointSetMetricRegistrationTestRun(
   for( unsigned int n=0; n < numberOfPoints; n ++ )
     {
     fixedPoint = fixedPoints->GetPoint( n );
-    movingPoint[0] = fixedPoint[0] * vcl_cos( theta ) - fixedPoint[1] * vcl_sin( theta );
-    movingPoint[1] = fixedPoint[0] * vcl_sin( theta ) + fixedPoint[1] * vcl_cos( theta );
+    movingPoint[0] = fixedPoint[0] * std::cos( theta ) - fixedPoint[1] * std::sin( theta );
+    movingPoint[1] = fixedPoint[0] * std::sin( theta ) + fixedPoint[1] * std::cos( theta );
     movingPoints->SetPoint( n, movingPoint );
     std::cout << fixedPoint << " -> " << movingPoint << std::endl;
     }
@@ -161,7 +161,7 @@ int itkEuclideanDistancePointSetMetricRegistrationTestRun(
     }
 
   // applying the resultant transform and verify result
-  std::cout << "Fixed\tMoving\tTransformed Fixed\tDiff" << std::endl;
+  std::cout << "Fixed\tMoving\tMovingTransformed\tFixedTransformed\tDiff" << std::endl;
   bool passed = true;
   typename PointType::ValueType tolerance = static_cast<typename PointType::ValueType>( 1e-4 );
   typename TTransform::InverseTransformBasePointer fixedInverse = metric->GetFixedTransform()->GetInverseTransform();
