@@ -40,12 +40,12 @@ protected:
 
 public:
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  virtual void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *) caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  virtual void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     if( typeid( event ) != typeid( itk::IterationEvent ) )
       {
@@ -91,13 +91,13 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
     {
     float radius = 100.0;
     PointType fixedPoint;
-    fixedPoint[0] = 2 * radius * vcl_cos( theta );
-    fixedPoint[1] = radius * vcl_sin( theta );
+    fixedPoint[0] = 2 * radius * std::cos( theta );
+    fixedPoint[1] = radius * std::sin( theta );
     fixedPoints->SetPoint( count, fixedPoint );
 
     PointType movingPoint;
-    movingPoint[0] = 2 * radius * vcl_cos( theta + (0.02 * vnl_math::pi) ) + 2.0;
-    movingPoint[1] = radius * vcl_sin( theta + (0.02 * vnl_math::pi) ) + 2.0;
+    movingPoint[0] = 2 * radius * std::cos( theta + (0.02 * vnl_math::pi) ) + 2.0;
+    movingPoint[1] = radius * std::sin( theta + (0.02 * vnl_math::pi) ) + 2.0;
     movingPoints->SetPoint( count, movingPoint );
 
     count++;
@@ -115,11 +115,11 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
     {
     PointType fixedPoint;
     float radius = 100.0;
-    fixedPoint[0] = radius * vcl_cos( theta );
-    fixedPoint[1] = radius * vcl_sin( theta );
+    fixedPoint[0] = radius * std::cos( theta );
+    fixedPoint[1] = radius * std::sin( theta );
     if( Dimension > 2 )
       {
-      fixedPoint[2] = radius * vcl_sin( theta );
+      fixedPoint[2] = radius * std::sin( theta );
       }
     fixedPoints->SetPoint( count, fixedPoint );
 
@@ -179,7 +179,7 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
   std::cout << "Optimizer learning rate: " << optimizer->GetLearningRate() << std::endl;
 
   // applying the resultant transform to moving points and verify result
-  std::cout << "Fixed\tMoving\tMoving Transformed\tDiff" << std::endl;
+  std::cout << "Fixed\tMoving\tMovingTransformed\tFixedTransformed\tDiff" << std::endl;
   bool passed = true;
   PointType::ValueType tolerance = 1e-4;
   AffineTransformType::InverseTransformBasePointer movingInverse = metric->GetMovingTransform()->GetInverseTransform();
