@@ -105,7 +105,6 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
   typedef itk::Image<PixelType,ImageDimension>             ImageType;
   typedef itk::Vector<float,ImageDimension>                VectorType;
   typedef itk::Image<VectorType,ImageDimension>            FieldType;
-  typedef itk::Image<VectorType::ValueType,ImageDimension> FloatImageType;
   typedef ImageType::IndexType                             IndexType;
   typedef ImageType::SizeType                              SizeType;
   typedef ImageType::RegionType                            RegionType;
@@ -272,7 +271,7 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
   bool passed = true;
   try
     {
-    registrator->SetInput( NULL );
+    registrator->SetInput( ITK_NULLPTR );
     registrator->SetNumberOfIterations( 2 );
     registrator->Update();
     }
@@ -297,7 +296,7 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
   try
     {
     registrator->SetInput( caster->GetOutput() );
-    registrator->SetMovingImage( NULL );
+    registrator->SetMovingImage( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject & err )
@@ -321,7 +320,7 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
     {
     fptr = dynamic_cast<FunctionType *>(
       registrator->GetDifferenceFunction().GetPointer() );
-    fptr->SetMovingImageInterpolator( NULL );
+    fptr->SetMovingImageInterpolator( ITK_NULLPTR );
     registrator->SetInput( initField );
     registrator->Update();
     }
