@@ -124,8 +124,6 @@ int itkLevelSetMotionRegistrationFilterTest(int argc, char * argv [] )
   typedef itk::Image<PixelType,ImageDimension>  ImageType;
   typedef itk::Vector<float,ImageDimension>     VectorType;
   typedef itk::Image<VectorType,ImageDimension> FieldType;
-  typedef itk::Image<VectorType::ValueType,ImageDimension>
-                                                FloatImageType;
   typedef ImageType::IndexType                  IndexType;
   typedef ImageType::SizeType                   SizeType;
   typedef ImageType::RegionType                 RegionType;
@@ -322,7 +320,7 @@ int itkLevelSetMotionRegistrationFilterTest(int argc, char * argv [] )
   bool passed = true;
   try
     {
-    registrator->SetInput( NULL );
+    registrator->SetInput( ITK_NULLPTR );
     registrator->SetNumberOfIterations( 2 );
     registrator->Update();
     }
@@ -347,7 +345,7 @@ int itkLevelSetMotionRegistrationFilterTest(int argc, char * argv [] )
   try
     {
     registrator->SetInput( caster->GetOutput() );
-    registrator->SetMovingImage( NULL );
+    registrator->SetMovingImage( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject & err )
@@ -371,7 +369,7 @@ int itkLevelSetMotionRegistrationFilterTest(int argc, char * argv [] )
     {
     fptr = dynamic_cast<FunctionType *>(
       registrator->GetDifferenceFunction().GetPointer() );
-    fptr->SetMovingImageInterpolator( NULL );
+    fptr->SetMovingImageInterpolator( ITK_NULLPTR );
     registrator->SetInput( initField );
     registrator->Update();
     }
