@@ -146,8 +146,6 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
   typedef itk::Image<PixelType,ImageDimension>  ImageType;
   typedef itk::Vector<float,ImageDimension>     VectorType;
   typedef itk::Image<VectorType,ImageDimension> FieldType;
-  typedef itk::Image<VectorType::ValueType,ImageDimension>
-                                                FloatImageType;
   typedef ImageType::IndexType                  IndexType;
   typedef ImageType::SizeType                   SizeType;
   typedef ImageType::RegionType                 RegionType;
@@ -369,7 +367,7 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
     {
     passed = false;
     std::cout << "Set RegistrationFilter to NULL" << std::endl;
-    registrator->SetRegistrationFilter( NULL );
+    registrator->SetRegistrationFilter( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject& err )
@@ -392,7 +390,7 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
     {
     passed = false;
     std::cout << "Set FixedImagePyramid to NULL" << std::endl;
-    registrator->SetFixedImagePyramid( NULL );
+    registrator->SetFixedImagePyramid( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject& err )
@@ -416,7 +414,7 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
     {
     passed = false;
     std::cout << "Set MovingImagePyramid to NULL" << std::endl;
-    registrator->SetMovingImagePyramid( NULL );
+    registrator->SetMovingImagePyramid( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject& err )
@@ -438,7 +436,7 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
     {
     passed = false;
     std::cout << "Set FixedImage to NULL" << std::endl;
-    registrator->SetFixedImage( NULL );
+    registrator->SetFixedImage( ITK_NULLPTR );
     registrator->Update();
     }
   catch( itk::ExceptionObject& err )
