@@ -28,7 +28,7 @@
 #include "itkImageToImageMetricv4.h"
 #include "itkShrinkImageFilter.h"
 #include "itkTransform.h"
-#include "itkTransformParametersAdaptor.h"
+#include "itkTransformParametersAdaptorBase.h"
 
 #include <vector>
 
@@ -85,7 +85,10 @@ namespace itk
  *
  * \ingroup ITKRegistrationMethodsv4
  */
-template<typename TFixedImage, typename TMovingImage, typename TOutputTransform, typename TVirtualImage = TFixedImage>
+template<typename TFixedImage,
+         typename TMovingImage,
+         typename TOutputTransform=Transform<double, TFixedImage::ImageDimension,  TFixedImage::ImageDimension >,
+         typename TVirtualImage = TFixedImage>
 class ImageRegistrationMethodv4
 :public ProcessObject
 {
@@ -140,6 +143,9 @@ public:
    */
   typedef DataObjectDecorator<OutputTransformType>                    DecoratedOutputTransformType;
   typedef typename DecoratedOutputTransformType::Pointer              DecoratedOutputTransformPointer;
+  typedef DataObjectDecorator<InitialTransformType>                   DecoratedInitialTransformType;
+  typedef typename DecoratedInitialTransformType::Pointer             DecoratedInitialTransformPointer;
+
 
   typedef ShrinkImageFilter<FixedImageType, VirtualImageType>         ShrinkFilterType;
   typedef typename ShrinkFilterType::ShrinkFactorsType                ShrinkFactorsPerDimensionContainerType;
@@ -150,7 +156,7 @@ public:
   typedef Array<RealType>                                             MetricSamplingPercentageArrayType;
 
   /** Transform adaptor typedefs */
-  typedef TransformParametersAdaptor<OutputTransformType>             TransformParametersAdaptorType;
+  typedef TransformParametersAdaptorBase<InitialTransformType>        TransformParametersAdaptorType;
   typedef typename TransformParametersAdaptorType::Pointer            TransformParametersAdaptorPointer;
   typedef std::vector<TransformParametersAdaptorPointer>              TransformParametersAdaptorsContainerType;
 
@@ -221,12 +227,27 @@ public:
   itkGetConstMacro( MetricSamplingPercentagePerLevel, MetricSamplingPercentageArrayType );
 
   /** Set/Get the initial fixed transform. */
-  itkSetObjectMacro( FixedInitialTransform, InitialTransformType );
-  itkGetModifiableObjectMacro( FixedInitialTransform, InitialTransformType );
+  itkSetGetDecoratedObjectInputMacro( FixedInitialTransform, InitialTransformType );
 
   /** Set/Get the initial moving transform. */
-  itkSetObjectMacro( MovingInitialTransform, InitialTransformType );
-  itkGetModifiableObjectMacro( MovingInitialTransform, InitialTransformType );
+  itkSetGetDecoratedObjectInputMacro( MovingInitialTransform, InitialTransformType );
+
+  /** Set/Get the initial transform to be optimized
+   *
+   * This transform is composed with the MovingInitialTransform to
+   * specify the initial transformation from the moving image to
+   * the virtual image. It is used for the default parameters, and can
+   * be use to specify the transform type.
+   *
+   * If the filter has "InPlace" set then this transform will be the
+   * output transform object or "grafted" to the output. Otherwise,
+   * this InitialTransform will be deep copied or "cloned" to the
+   * output.
+   *
+   * If this parameter is not set then a default constructed output
+   * transform is used.
+   */
+  itkSetGetDecoratedObjectInputMacro(InitialTransform, InitialTransformType);
 
   /** Set/Get the transform adaptors. */
   void SetTransformParametersAdaptorsPerLevel( TransformParametersAdaptorsContainerType & );
@@ -303,11 +324,18 @@ public:
   /** Make a DataObject of the correct type to be used as the specified output. */
   typedef ProcessObject::DataObjectPointerArraySizeType DataObjectPointerArraySizeType;
   using Superclass::MakeOutput;
-  virtual DataObjectPointer MakeOutput( DataObjectPointerArraySizeType );
+  virtual DataObjectPointer MakeOutput( DataObjectPointerArraySizeType ) ITK_OVERRIDE;
 
   /** Returns the transform resulting from the registration process  */
+  virtual DecoratedOutputTransformType * GetOutput();
   virtual const DecoratedOutputTransformType * GetOutput() const;
 
+  virtual DecoratedOutputTransformType * GetTransformOutput() { return this->GetOutput(); }
+  virtual const DecoratedOutputTransformType * GetTransformOutput() const { return this->GetOutput(); }
+
+  virtual OutputTransformType * GetModifiableTransform();
+  virtual const OutputTransformType * GetTransform() const;
+
   /** Get the current level.  This is a helper function for reporting observations. */
   itkGetConstMacro( CurrentLevel, SizeValueType );
 
@@ -323,6 +351,14 @@ public:
    /** Get the current convergence state per level.  This is a helper function for reporting observations. */
    itkGetConstReferenceMacro( IsConverged, bool );
 
+  /** Request that the InitialTransform be grafted onto the output,
+   * there by not creating a copy.
+   */
+  itkSetMacro(InPlace, bool);
+  itkGetConstMacro(InPlace, bool);
+  itkBooleanMacro(InPlace);
+
+
 #ifdef ITKV3_COMPATIBILITY
   /** Method that initiates the registration. This will Initialize and ensure
    * that all inputs the registration needs are in place, via a call to
@@ -345,10 +381,12 @@ public:
 protected:
   ImageRegistrationMethodv4();
   virtual ~ImageRegistrationMethodv4();
-  virtual void PrintSelf( std::ostream & os, Indent indent ) const;
+  virtual void PrintSelf( std::ostream & os, Indent indent ) const ITK_OVERRIDE;
 
   /** Perform the registration. */
-  virtual void  GenerateData();
+  virtual void  GenerateData() ITK_OVERRIDE;
+
+  virtual void AllocateOutputs();
 
   /** Initialize by setting the interconnects between the components. */
   virtual void InitializeRegistrationAtEachLevel( const SizeValueType );
@@ -380,18 +418,33 @@ protected:
   SmoothingSigmasArrayType                                        m_SmoothingSigmasPerLevel;
   bool                                                            m_SmoothingSigmasAreSpecifiedInPhysicalUnits;
 
-  InitialTransformPointer                                         m_MovingInitialTransform;
-  InitialTransformPointer                                         m_FixedInitialTransform;
-
   TransformParametersAdaptorsContainerType                        m_TransformParametersAdaptorsPerLevel;
 
   CompositeTransformPointer                                       m_CompositeTransform;
 
+  //TODO: m_OutputTransform should be removed and replaced with a named input parameter for
+  //      the pipeline  --- Along with many other fixes
   OutputTransformPointer                                          m_OutputTransform;
 
+
 private:
   ImageRegistrationMethodv4( const Self & );   //purposely not implemented
-  void operator=( const Self & );                  //purposely not implemented
+  void operator=( const Self & );              //purposely not implemented
+
+  bool                                                            m_InPlace;
+
+  // helper function to create the right kind of concrete transform
+  template<typename TTransform>
+  static void MakeOutputTransform(SmartPointer<TTransform> &ptr)
+    {
+      ptr = TTransform::New();
+    }
+
+  static void MakeOutputTransform(SmartPointer<InitialTransformType> &ptr)
+    {
+      ptr = itk::IdentityTransform<RealType, ImageDimension>::New().GetPointer();
+    }
+
 };
 } // end namespace itk
 
