@@ -25,14 +25,6 @@
 namespace itk
 {
 
-// Forward-declare these because of module dependency conflict.
-// They will soon be moved to a different module, at which
-// time this can be removed.
-template <unsigned int VDimension, typename TDataHolder>
-class ImageToData;
-template <typename TDataHolder>
-class Array1DToData;
-
 /** \class TimeVaryingVelocityFieldImageRegistrationMethodv4
  * \brief Interface method for the current registration framework
  * using the time varying velocity field transform.
