@@ -40,12 +40,12 @@ protected:
 
 public:
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  virtual void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *) caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  virtual void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     const TFilter * filter =
       dynamic_cast< const TFilter * >( object );
@@ -57,9 +57,9 @@ public:
     typename TFilter::SmoothingSigmasArrayType smoothingSigmas = filter->GetSmoothingSigmasPerLevel();
     typename TFilter::TransformParametersAdaptorsContainerType adaptors = filter->GetTransformParametersAdaptorsPerLevel();
 
-    typename itk::ObjectToObjectOptimizerBase::Pointer optimizerBase = (const_cast<TFilter*>(filter))->GetModifiableOptimizer();
+    const itk::ObjectToObjectOptimizerBase * optimizerBase = filter->GetOptimizer();
     typedef itk::GradientDescentOptimizerv4 GradientDescentOptimizerv4Type;
-    typename GradientDescentOptimizerv4Type::Pointer optimizer = dynamic_cast<GradientDescentOptimizerv4Type *>(optimizerBase.GetPointer());
+    typename GradientDescentOptimizerv4Type::ConstPointer optimizer = dynamic_cast<const GradientDescentOptimizerv4Type *>(optimizerBase);
     if( !optimizer )
       {
       itkGenericExceptionMacro( "Error dynamic_cast failed" );
@@ -211,7 +211,7 @@ int PerformBSplineImageRegistration( int argc, char *argv[] )
 
   typedef itk::CompositeTransform<RealType, VImageDimension> CompositeTransformType;
   typename CompositeTransformType::Pointer compositeTransform = CompositeTransformType::New();
-  compositeTransform->AddTransform( const_cast<typename AffineRegistrationType::OutputTransformType *>( affineSimple->GetOutput()->Get() ) );
+  compositeTransform->AddTransform( affineSimple->GetModifiableTransform() );
 
   const unsigned int numberOfLevels = 3;
   const unsigned int SplineOrder = 3;
@@ -236,8 +236,7 @@ int PerformBSplineImageRegistration( int argc, char *argv[] )
   smoothingSigmasPerLevel[1] = 1;
   smoothingSigmasPerLevel[2] = 1;
 
-  typename BSplineTransformType::Pointer outputBSplineTransform =
-    const_cast<BSplineTransformType *>( bsplineRegistration->GetOutput()->Get() );
+  typename BSplineTransformType::Pointer outputBSplineTransform =  BSplineTransformType::New();
 
   typename BSplineTransformType::PhysicalDimensionsType physicalDimensions;
   typename BSplineTransformType::MeshSizeType meshSize;
@@ -249,7 +248,6 @@ int PerformBSplineImageRegistration( int argc, char *argv[] )
 
   // Create the transform adaptors
 
-  typedef itk::BSplineTransformParametersAdaptor<BSplineTransformType> BSplineTransformAdaptorType;
   typename BSplineRegistrationType::TransformParametersAdaptorsContainerType adaptors;
   // Create the transform adaptors specific to B-splines
   for( unsigned int level = 0; level < numberOfLevels; level++ )
@@ -295,6 +293,9 @@ int PerformBSplineImageRegistration( int argc, char *argv[] )
   outputBSplineTransform->SetTransformDomainDirection( fixedImage->GetDirection() );
   outputBSplineTransform->SetIdentity();
 
+  bsplineRegistration->SetInitialTransform( outputBSplineTransform );
+  bsplineRegistration->InPlaceOn();
+
   typedef CommandIterationUpdate<BSplineRegistrationType> BSplineRegistrationCommandType;
   typename BSplineRegistrationCommandType::Pointer bsplineObserver = BSplineRegistrationCommandType::New();
   bsplineRegistration->AddObserver( itk::IterationEvent(), bsplineObserver );
@@ -310,7 +311,7 @@ int PerformBSplineImageRegistration( int argc, char *argv[] )
     return EXIT_FAILURE;
     }
 
-  compositeTransform->AddTransform( const_cast<BSplineTransformType *>( bsplineRegistration->GetOutput()->Get() ) );
+  compositeTransform->AddTransform( bsplineRegistration->GetModifiableTransform() );
 
   std::cout << "After displacement registration: " << std::endl
             << "Last LearningRate: " << optimizer->GetLearningRate() << std::endl
