@@ -48,13 +48,13 @@ const unsigned int WIDTH  = (128);
 float square(unsigned x, unsigned y)
 {
     float X, Y;
-    X = vcl_fabs(x - (float)WIDTH/2.0);
-    Y = vcl_fabs(y - (float)HEIGHT/2.0);
+    X = std::fabs(x - (float)WIDTH/2.0);
+    Y = std::fabs(y - (float)HEIGHT/2.0);
     float dis;
     if (!((X > RADIUS)&&(Y > RADIUS)))
       dis = RADIUS - vnl_math_max(X, Y);
     else
-      dis = -vcl_sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
+      dis = -std::sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
     return(dis);
 }
 
