@@ -89,7 +89,7 @@ int itkVTKVisualize2DDenseImageLevelSetTest( int , char* [] )
     LevelSetOutputType value =
         static_cast< LevelSetOutputType >( ( idx[0] - 25 ) * ( idx[0] - 25 ) +
                                            ( idx[1] - 25 ) * ( idx[1] - 25 ) );
-    value = vcl_sqrt( value ) - 20;
+    value = std::sqrt( value ) - 20;
     it.Set( value );
     ++it;
     }
