@@ -68,7 +68,7 @@ public:
   FrameOffsetType GetFrameDuration() const;
 
   /** Return RegionType (SRUCTURED_REGION) */
-  virtual RegionType GetRegionType() const;
+  virtual RegionType GetRegionType() const ITK_OVERRIDE;
 
   /** Constructor */
   TemporalRegion();
@@ -89,7 +89,7 @@ public:
 
 protected:
 
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Time boundaries */
   RealTimeStamp    m_RealStart;
