@@ -100,11 +100,11 @@ public:
 
   /** Aliased to the Write() method to be consistent with the rest of the
    * pipeline. */
-  virtual void Update();
+  virtual void Update() ITK_OVERRIDE;
 
   /** Write the entire video to a file, if possible. This is the same as
    * calling write or update without setting an output temporal region. */
-  virtual void UpdateLargestPossibleRegion();
+  virtual void UpdateLargestPossibleRegion() ITK_OVERRIDE;
 
 protected:
 
@@ -112,7 +112,7 @@ protected:
 
   VideoFileWriter();
   virtual ~VideoFileWriter();
-  void PrintSelf(std::ostream &os, Indent indent) const;
+  virtual void PrintSelf(std::ostream &os, Indent indent) const ITK_OVERRIDE;
 
   /** Initialize output parameters */
   bool InitializeOutputParameters();
@@ -123,7 +123,7 @@ protected:
   bool InitializeVideoIO();
 
   /** Override TemporalStreamingGenerateData to do the actual writing. */
-  virtual void TemporalStreamingGenerateData();
+  virtual void TemporalStreamingGenerateData() ITK_OVERRIDE;
 
   /**-PROTECTED MEMBERS------------------------------------------------------*/
 
